@@ -1,5 +1,4 @@
-/* Time-stamp: <2007-02-23 00:04:30 jcs>
-|
+/*
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
 | 
@@ -24,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: confirmation.c 995 2007-02-22 15:05:53Z jcsjcs $
+|  $Id: confirmation.c 2209 2009-01-13 13:45:55Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -211,6 +210,30 @@ static void on_response (GtkWidget *w, gint response, gpointer id)
     }
 }
 
+static void confirm_append_text (GladeXML *xml, const gchar *text)
+{
+	int i;
+	gchar **strings = g_strsplit (text, "\n", 0);
+	GtkTreeIter iter;
+	GtkAdjustment *adjustment;
+	GtkWidget *w = gtkpod_xml_get_widget (xml, "tree");
+	GtkListStore *store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (w)));
+	
+	for (i = 0; strings[i]; i++)
+	{
+		if (strings[i][0])
+		{
+			gtk_list_store_append (store, &iter);
+			gtk_list_store_set (store, &iter, 0, strings[i], -1);
+		}
+	}
+	
+	w = gtkpod_xml_get_widget (xml, "scroller");
+	adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (w));
+	gtk_adjustment_set_value (adjustment, adjustment->upper - adjustment->page_size);
+	
+	g_strfreev (strings);
+}
 
 /* gtkpod_confirmation(): open a confirmation window with the
    information given. If "OK" is clicked, ok_handler() is called,
@@ -296,39 +319,24 @@ GtkResponseType gtkpod_confirmation (gint id,
     ConfData *cd;
     gint defx, defy;
     GladeXML *confirm_xml;
+    GtkListStore *store;
+    GtkTreeViewColumn *column;
+    GtkCellRenderer *renderer;
+    gchar *full_label;
 
     if (id_hash == NULL)
     {  /* initialize hash table to store IDs */
 	id_hash = g_hash_table_new_full (g_direct_hash, g_direct_equal,
-					      NULL, g_free);
+							  NULL, g_free);
     }
+	
     if (id >= 0)
     {
 	if ((cd = g_hash_table_lookup (id_hash, GINT_TO_POINTER(id))))
-	{ /* window with same ID already open -- add @text and return
-	   * */
-	    if (text && *text &&
-		cd->window && ((w = gtkpod_xml_get_widget (cd->window_xml, "text"))))
+	{ /* window with same ID already open -- add @text and return */
+	    if (text && *text && cd->window)
 	    {
-		GtkTextIter ti;
-		GtkTextBuffer *tb = gtk_text_view_get_buffer(GTK_TEXT_VIEW(w));
-		if (!tb)
-		{   /* text buffer doesn't exist yet */
-		    GtkWidget *w1;
-		    tb = gtk_text_buffer_new(NULL);
-		    gtk_text_view_set_buffer(GTK_TEXT_VIEW(w), tb);
-		    gtk_text_view_set_editable(GTK_TEXT_VIEW(w), FALSE);
-		    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(w), FALSE);
-		    if ((w1 =  gtkpod_xml_get_widget (cd->window_xml, "scroller")))
-			gtk_widget_show (w1);
-		    cd->scrolled = TRUE;
-		}
-		/* append new text to the end */
-		gtk_text_buffer_get_end_iter (tb, &ti);
-		gtk_text_buffer_insert (tb, &ti, text, -1);
-		/* scroll window such that new text is visible */
-		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (w),
-                                    gtk_text_buffer_get_insert (tb));
+		confirm_append_text (cd->window_xml, text);
 	    }
 	    return GTK_RESPONSE_REJECT;
 	}
@@ -336,6 +344,7 @@ GtkResponseType gtkpod_confirmation (gint id,
     else /* find free ID */
     {
 	id = 0;
+
 	do
 	{
 	    --id;
@@ -344,20 +353,25 @@ GtkResponseType gtkpod_confirmation (gint id,
     }
 
     if (!confirm_again)
-    { /* This question was supposed to be asked "never again" ("don't
-	 confirm again" -- so we just call the ok_handler */
+    {
+	/* This question was supposed to be asked "never again" ("don't
+	   confirm again" -- so we just call the ok_handler */
 	if (ok_handler && !modal)
 	    ok_handler (user_data1, user_data2);
-	if (!modal)  return GTK_RESPONSE_ACCEPT;
-	else         return GTK_RESPONSE_OK;
+
+	if (!modal) 
+	    return GTK_RESPONSE_ACCEPT;
+
+	return GTK_RESPONSE_OK;
     }
 
     /* window = create_confirm_dialog (); */
-    confirm_xml = glade_xml_new (xml_file, "confirm_dialog", NULL);
+    confirm_xml = gtkpod_xml_new (xml_file, "confirm_dialog");
     window = gtkpod_xml_get_widget (confirm_xml, "confirm_dialog");
-
+    glade_xml_signal_autoconnect (confirm_xml);
+	
     /* insert ID into hash table */
-    cd = g_malloc (sizeof (ConfData));
+    cd = g_new0 (ConfData, 1);
     cd->window = window;
     cd->window_xml = confirm_xml;
     cd->option1_key = g_strdup(option1_key);
@@ -369,65 +383,79 @@ GtkResponseType gtkpod_confirmation (gint id,
     cd->user_data1 = user_data1;
     cd->user_data2 = user_data2;
     g_hash_table_insert (id_hash, GINT_TO_POINTER(id), cd);
-
-    /* Set title */
-    if (title)
-	gtk_window_set_title (GTK_WINDOW(window), title);
-    else
-	gtk_window_set_title (GTK_WINDOW(window), _("Confirmation Dialogue"));
+	
+    full_label = g_markup_printf_escaped ("<span weight='bold' size='larger'>%s</span>\n\n%s",
+					  title ? title : _("Confirmation"), label ? label : "");
 
     /* Set label */
     w = gtkpod_xml_get_widget (confirm_xml, "label");
-    if (label)
-    {
-	gtk_widget_show (w);
-	gtk_label_set_text(GTK_LABEL(w), label);
-    }
-    else
-    {
-	gtk_widget_hide (w);
-    }
+    gtk_label_set_markup (GTK_LABEL(w), full_label);
+    g_free (full_label);
 
     /* Set text */
-    w = gtkpod_xml_get_widget (confirm_xml, "text");
+    w = gtkpod_xml_get_widget (confirm_xml, "tree");
+    store = gtk_list_store_new (1, G_TYPE_STRING);
+    gtk_tree_view_set_model (GTK_TREE_VIEW (w), GTK_TREE_MODEL (store));
+    g_object_unref (store);
+
+    column = gtk_tree_view_column_new ();
+    renderer = gtk_cell_renderer_text_new ();
+
+/*
+    gint mode, width;
+
+    g_object_get (G_OBJECT (renderer),
+		  "wrap-mode", &mode,
+		  "wrap-width", &width,
+		  NULL);
+
+    printf ("wrap-mode: %d wrap-width:%d\n", mode, width);
+*/
+
+    /* I have no idea why 400, but neither 1000 nor 0 result in the
+       right behavior... */
+    g_object_set (G_OBJECT (renderer),
+		  "wrap-mode", PANGO_WRAP_WORD_CHAR,
+		  "wrap-width", 400,
+		  NULL);
+
+    gtk_tree_view_column_pack_start (column, renderer, TRUE);
+    gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
+    g_object_set_data (G_OBJECT (w), "renderer", renderer);
+
+    gtk_tree_view_append_column (GTK_TREE_VIEW (w), column);
+
     if (text)
     {
-	if (w)
-	{
-	    GtkTextBuffer *tb = gtk_text_buffer_new(NULL);
-	    gtk_text_buffer_set_text(tb, text, strlen(text));
-	    gtk_text_view_set_buffer(GTK_TEXT_VIEW(w), tb);
-	    gtk_text_view_set_editable(GTK_TEXT_VIEW(w), FALSE);
-	    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(w), FALSE);
-	}
-	cd->scrolled = TRUE;
-	defx = prefs_get_int("size_conf_sw.x");
-	defy = prefs_get_int("size_conf_sw.y");
+		confirm_append_text (cd->window_xml, text);
+		cd->scrolled = TRUE;
+		defx = prefs_get_int("size_conf_sw.x");
+		defy = prefs_get_int("size_conf_sw.y");
     }
     else
-    { /* no text -> hide widget */
-	if ((w = gtkpod_xml_get_widget (confirm_xml, "scroller")))
-	    gtk_widget_hide (w);
-	cd->scrolled = FALSE;
-	defx = prefs_get_int("size_conf.x");
-	defy = prefs_get_int("size_conf.y");
+    {
+		/* no text -> hide widget */
+		if ((w = gtkpod_xml_get_widget (confirm_xml, "scroller")))
+			gtk_widget_hide (w);
+		
+		cd->scrolled = FALSE;
+		defx = prefs_get_int("size_conf.x");
+		defy = prefs_get_int("size_conf.y");
     }
-    gtk_window_set_default_size (GTK_WINDOW (window), defx, defy);
+	
+    gtk_widget_set_size_request (GTK_WIDGET (window), defx, defy);
 
     /* Set "Option 1" checkbox */
     w = gtkpod_xml_get_widget (confirm_xml, "option_vbox");
+	
     if (w && option1_key && option1_text)
     {
 	gboolean state, invert;
 	GtkWidget *option1_button =
 	    gtk_check_button_new_with_mnemonic (option1_text);
 
-	if ((option1_state==CONF_STATE_INVERT_TRUE) ||
-	    (option1_state==CONF_STATE_TRUE))  state = TRUE;
-	else                                   state = FALSE;
-	if ((option1_state==CONF_STATE_INVERT_FALSE) ||
-	    (option1_state==CONF_STATE_INVERT_TRUE))  invert = TRUE;
-	else                                          invert = FALSE;
+	state = ((option1_state==CONF_STATE_INVERT_TRUE) || (option1_state==CONF_STATE_TRUE));
+	invert = ((option1_state==CONF_STATE_INVERT_FALSE) || (option1_state==CONF_STATE_INVERT_TRUE));
 	cd->option1_invert = invert;
 
 	gtk_widget_show (option1_button);
@@ -448,12 +476,8 @@ GtkResponseType gtkpod_confirmation (gint id,
 	GtkWidget *option2_button =
 	    gtk_check_button_new_with_mnemonic (option2_text);
 
-	if ((option2_state==CONF_STATE_INVERT_TRUE) ||
-	    (option2_state==CONF_STATE_TRUE))  state = TRUE;
-	else                                   state = FALSE;
-	if ((option2_state==CONF_STATE_INVERT_FALSE) ||
-	    (option2_state==CONF_STATE_INVERT_TRUE))  invert = TRUE;
-	else                                          invert = FALSE;
+	state = ((option2_state==CONF_STATE_INVERT_TRUE) || (option2_state==CONF_STATE_TRUE));
+	invert = ((option2_state==CONF_STATE_INVERT_FALSE) || (option2_state==CONF_STATE_INVERT_TRUE));
 	cd->option2_invert = invert;
 
 	gtk_widget_show (option2_button);
@@ -468,8 +492,10 @@ GtkResponseType gtkpod_confirmation (gint id,
 
     /* Set "Never Again" checkbox */
     w = gtkpod_xml_get_widget (confirm_xml, "never_again");
+
     if (w && confirm_again_key)
-    { /* connect signal */
+    {
+	/* connect signal */
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w),
 				     !confirm_again);
 	g_signal_connect ((gpointer)w,
@@ -478,7 +504,8 @@ GtkResponseType gtkpod_confirmation (gint id,
 			  GINT_TO_POINTER(id));
     }
     else if (w)
-    { /* hide "never again" button */
+    {
+	/* hide "never again" button */
 	gtk_widget_hide (w);
     }
 
@@ -489,7 +516,9 @@ GtkResponseType gtkpod_confirmation (gint id,
     {
 	GTK_WIDGET_SET_FLAGS (w, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default (w);
-	if (!cancel_handler)  gtk_widget_hide (w);
+	
+	if (!cancel_handler)
+	    gtk_widget_hide (w);
     }
 
     /* Hide or default APPLY button */
@@ -497,7 +526,9 @@ GtkResponseType gtkpod_confirmation (gint id,
     {
 	GTK_WIDGET_SET_FLAGS (w, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default (w);
-	if (!apply_handler)   gtk_widget_hide (w);
+
+	if (!apply_handler)
+	    gtk_widget_hide (w);
     }
 
     /* Hide or default OK button */
@@ -505,7 +536,9 @@ GtkResponseType gtkpod_confirmation (gint id,
     {
 	GTK_WIDGET_SET_FLAGS (w, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default (w);
-	if (!ok_handler)     gtk_widget_hide (w);
+
+	if (!ok_handler)
+	    gtk_widget_hide (w);
     }
 
     /* Connect Close window */
@@ -520,6 +553,7 @@ GtkResponseType gtkpod_confirmation (gint id,
 	gint response = gtk_dialog_run (GTK_DIALOG (window));
 	/* cleanup hash, store window size */
 	cleanup (GINT_TO_POINTER(id));
+
 	switch (response)
 	{
 	case GTK_RESPONSE_OK:
@@ -537,6 +571,69 @@ GtkResponseType gtkpod_confirmation (gint id,
 			  G_CALLBACK (on_response),
 			  GINT_TO_POINTER(id));
 	gtk_widget_show (window);
+
 	return GTK_RESPONSE_ACCEPT;
     }
 }
+
+G_MODULE_EXPORT void on_confirm_tree_size_allocate (GtkWidget *sender, GtkAllocation *allocation, gpointer e)
+{
+    GtkCellRenderer *renderer = GTK_CELL_RENDERER (g_object_get_data (G_OBJECT (sender), "renderer"));
+    g_object_set (renderer, "wrap-width", allocation->width, NULL);
+}
+
+gint gtkpod_confirmation_simple (GtkWindow *parent,
+				 GtkMessageType icon,
+				 const gchar *primary_text,
+				 const gchar *secondary_text,
+				 const gchar *accept_button_text)
+{
+    return gtkpod_confirmation_hig(parent, icon, primary_text, secondary_text,
+				   accept_button_text, NULL, NULL, NULL);
+}
+
+gint gtkpod_confirmation_hig (GtkWindow *parent,
+			      GtkMessageType icon,
+			      const gchar *primary_text,
+			      const gchar *secondary_text,
+			      const gchar *accept_button_text,
+			      const gchar *cancel_button_text,
+			      const gchar *third_button_text,
+			      const gchar *help_context)
+{
+    gint result;
+
+    GtkWidget *dialog =
+	gtk_message_dialog_new(parent,
+			       GTK_DIALOG_MODAL,
+			       icon,
+			       GTK_BUTTONS_NONE,
+			       "%s",
+			       primary_text);
+
+    gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG(dialog),
+						"%s",
+						secondary_text);
+
+    if(third_button_text)
+	gtk_dialog_add_button(GTK_DIALOG(dialog), third_button_text, GTK_RESPONSE_APPLY);
+
+    gtk_dialog_add_buttons(GTK_DIALOG(dialog),
+			   cancel_button_text ? cancel_button_text : GTK_STOCK_CANCEL,
+			   GTK_RESPONSE_CANCEL,
+			   accept_button_text ? accept_button_text : GTK_STOCK_OK,
+			   GTK_RESPONSE_OK,
+			   NULL);
+
+    result = gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(dialog);
+
+    switch (result)
+    {
+    case GTK_RESPONSE_OK:
+    case GTK_RESPONSE_APPLY:
+	return result;
+    default:
+	return GTK_RESPONSE_CANCEL;
+    };
+}
