@@ -22,7 +22,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: confirmation.h 1065 2007-05-06 14:16:17Z jcsjcs $
+|  $Id: confirmation.h 1842 2007-12-18 18:11:45Z Sikon $
 */
 
 #ifndef __CONFIRMATION_H__
@@ -64,6 +64,21 @@ GtkResponseType gtkpod_confirmation (gint id,
 				     gpointer user_data1,
 				     gpointer user_data2);
 
+gint gtkpod_confirmation_simple (GtkWindow *parent,
+								 GtkMessageType icon,
+								 const gchar *primary_text,
+								 const gchar *secondary_text,
+								 const gchar *accept_button_text);
+
+gint gtkpod_confirmation_hig (GtkWindow *parent,
+							  GtkMessageType icon,
+							  const gchar *primary_text,
+							  const gchar *secondary_text,
+							  const gchar *accept_button_text,
+							  const gchar *cancel_button_text,
+							  const gchar *third_button_text,
+							  const gchar *help_context);
+
 /* predefined IDs for use with gtkpod_confirmation() */
 enum {
     CONF_ID_IPOD_DIR = 0,
