@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: details.c 1755 2007-11-05 01:16:19Z phantom_sf $
+|  $Id: details.c 2149 2008-11-08 09:38:35Z jcsjcs $
 */
 
 /* This file provides functions for the details window */
@@ -54,7 +54,7 @@ static GList *details = NULL;
 /* string constants for preferences */
 static const gchar *DETAILS_WINDOW_DEFX="details_window_defx";
 static const gchar *DETAILS_WINDOW_DEFY="details_window_defy";
-static const gchar *DETAILS_WINDOW_NOTEBOOK_PAGE="details_window_notebook_page";
+const gchar *DETAILS_WINDOW_NOTEBOOK_PAGE="details_window_notebook_page";
 
 /* enum types */
 typedef enum
@@ -436,8 +436,8 @@ static void details_button_apply_clicked (GtkButton *button,
 	    {
 		Track *tr = gl->data;
 		write_tags_to_file (tr);
-		/* display possible duplicates that have been removed */
 	    }
+	    /* display possible duplicates that have been removed */
 	    gp_duplicate_remove (NULL, NULL);
 	}
     }
@@ -571,7 +571,7 @@ static gboolean details_copy_artwork (Track *frtrack, Track *totrack)
 	}
     /* make sure artwork gets removed, even if both thumb_paths were
        unset ("") */
-    if (!frtrack->artwork->thumbnails)
+    if (!itdb_track_has_thumbnails (frtrack))
     {
 	changed |= gp_track_remove_thumbnails (totrack);
     }
@@ -779,6 +779,7 @@ static void details_setup_widget (Detail *detail, T_item item)
 	break;
     case T_DESCRIPTION:
     case T_SUBTITLE:
+    case T_LYRICS:
     case T_COMMENT:
 	buf = g_strdup_printf ("details_textview_%d", item);
 	w = gtkpod_xml_get_widget (detail->xml, buf);
@@ -896,6 +897,7 @@ static void details_set_item (Detail *detail, Track *track, T_item item)
 	break;
     case T_COMMENT:
     case T_DESCRIPTION:
+    case T_LYRICS:
     case T_SUBTITLE:
 	w = gtkpod_xml_get_widget (detail->xml, textview);
 	tb= gtk_text_view_get_buffer (GTK_TEXT_VIEW (w));
@@ -1119,6 +1121,7 @@ static void details_get_item (Detail *detail, T_item item,
     case T_COMMENT:
     case T_DESCRIPTION:
     case T_SUBTITLE:
+    case T_LYRICS:
 	if ((w = gtkpod_xml_get_widget (detail->xml, textview)))
 	{
 	    gchar *text;
@@ -1131,6 +1134,8 @@ static void details_get_item (Detail *detail, T_item item,
 	    text = gtk_text_buffer_get_text (tb, &start, &end, TRUE);
 
 	    changed = track_set_text (track, text, item);
+
+	    g_free (text);
 	}
 	break;
     case T_COMPILATION:
@@ -1286,12 +1291,12 @@ void details_update_buttons (Detail *detail)
 	    {
 		Track *tr = gl->data;
 		g_return_if_fail (tr);
-		remove_artwork |= (tr->artwork->thumbnails != NULL);
+		remove_artwork |= itdb_track_has_thumbnails (tr);
 	    }
 	}
 	else
 	{
-	    remove_artwork = (detail->track->artwork->thumbnails != NULL);
+	    remove_artwork = (itdb_track_has_thumbnails (detail->track));
 	}
 	i = g_list_index (detail->tracks, detail->track);
 	g_return_if_fail (i != -1);
@@ -1354,7 +1359,6 @@ void details_update_buttons (Detail *detail)
 /* Update the displayed thumbnail */
 void details_update_thumbnail (Detail *detail)
 {
-    Thumb *thumb;
     GtkImage *img;
 
     g_return_if_fail (detail);
@@ -1368,25 +1372,20 @@ void details_update_thumbnail (Detail *detail)
     {
 	detail->artwork_ok = TRUE;
 	/* Get large cover */
-	thumb = itdb_artwork_get_thumb_by_type (detail->track->artwork,
-						ITDB_THUMB_COVER_LARGE);
-	if (thumb)
-	{
-	    GdkPixbuf *pixbuf;
-	    pixbuf = itdb_thumb_get_gdk_pixbuf (detail->itdb->device,
-						thumb);
-	    if (pixbuf)
-	    {
-		gtk_image_set_from_pixbuf (img, pixbuf);
-		gdk_pixbuf_unref (pixbuf);
-	    }
-	    else
-	    {
-		gtk_image_set_from_stock (img, GTK_STOCK_DIALOG_WARNING,
-					  GTK_ICON_SIZE_DIALOG);
-		detail->artwork_ok = FALSE;
-	    }
-	}
+        GdkPixbuf *pixbuf = itdb_artwork_get_pixbuf (detail->itdb->device,
+						     detail->track->artwork,
+						     200, 200);
+        if (pixbuf)
+        {
+            gtk_image_set_from_pixbuf (img, pixbuf);
+            g_object_unref (pixbuf);
+        }
+        else
+        {
+            gtk_image_set_from_stock (img, GTK_STOCK_DIALOG_WARNING,
+                    GTK_ICON_SIZE_DIALOG);
+            detail->artwork_ok = FALSE;
+        }
 	details_set_item (detail,  detail->track, T_THUMB_PATH);
     }
 
@@ -1570,14 +1569,14 @@ void details_edit (GList *selected_tracks)
 {
     Detail *detail;
     GtkWidget *w;
-    gint defx, defy, page;
+    gint defx, defy, page, num_pages;
     T_item i;
 
     g_return_if_fail (selected_tracks);
 
     detail = g_malloc0 (sizeof (Detail));
 
-    detail->xml = glade_xml_new (xml_file, "details_window", NULL);
+    detail->xml = gtkpod_xml_new (xml_file, "details_window");
 /*  no signals to connect -> comment out */
 /*     glade_xml_signal_autoconnect (detail->xml); */
     detail->window = gtkpod_xml_get_widget (detail->xml, "details_window");
@@ -1686,7 +1685,8 @@ void details_edit (GList *selected_tracks)
     /* set notebook page */
     w = gtkpod_xml_get_widget (detail->xml, "details_notebook");
     page = prefs_get_int (DETAILS_WINDOW_NOTEBOOK_PAGE);
-    if ((page >= 0) && (page <= 4))
+    num_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (w));
+    if ((page >= 0) && (page < num_pages))
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (w), page);
 
     /* set default size */
@@ -1852,7 +1852,7 @@ static void dnd_details_art_drag_data_received(GtkWidget *widget, GdkDragContext
 					image_error = g_strdup(fcover->err_msg);
 								
 				free_fetchcover (fcover);
-				gdk_pixbuf_unref (pixbuf);
+				g_object_unref (pixbuf);
 				coverart_block_change (FALSE);
 			}
 			else
