@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_itdb.c 1723 2007-10-08 03:45:55Z tiffman $
+|  $Id: display_itdb.c 2148 2008-11-08 08:02:15Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -65,6 +65,8 @@ void gp_itdb_extra_destroy (ExtraiTunesDBData *eitdb)
     {
 	sha1_free_eitdb (eitdb);
 	gp_itdb_pc_path_hash_destroy (eitdb);
+	g_free (eitdb->offline_filename);
+	itdb_photodb_free (eitdb->photodb);
 	g_free (eitdb);
     }
 }
@@ -105,10 +107,15 @@ void gp_track_extra_destroy (ExtraTrackData *etrack)
     if (etrack)
     {
 	g_free (etrack->year_str);
+	g_free (etrack->pc_path_locale);
 	g_free (etrack->pc_path_utf8);
+	g_free (etrack->converted_file);
+	g_free (etrack->thumb_path_locale);
+	g_free (etrack->thumb_path_utf8);
 	g_free (etrack->hostname);
 	g_free (etrack->sha1_hash);
 	g_free (etrack->charset);
+	g_free (etrack->lyrics);
 	g_free (etrack);
     }
 }
@@ -131,6 +138,7 @@ ExtraTrackData *gp_track_extra_duplicate (ExtraTrackData *etr)
 	etr_dup->hostname = g_strdup (etr->hostname);
 	etr_dup->sha1_hash = g_strdup (etr->sha1_hash);
 	etr_dup->charset = g_strdup (etr->charset);
+	etr_dup->lyrics = g_strdup (etr->lyrics);
 	/* clear the pc_path_hashed flag */
 	etr_dup->pc_path_hashed = FALSE;
     }
@@ -251,10 +259,11 @@ void gp_track_add_extra (Track *track)
 {
     g_return_if_fail (track);
 
-    if (!track->userdata);
+    if (!track->userdata)
     {
 	ExtraTrackData *etr = g_new0 (ExtraTrackData, 1);
 	track->userdata = etr;
+	etr->lyrics=NULL;
 	track->userdata_destroy =
 	    (ItdbUserDataDestroyFunc)gp_track_extra_destroy;
 	track->userdata_duplicate =
@@ -416,7 +425,7 @@ gboolean gp_track_remove_thumbnails (Track *track)
     etr = track->userdata;
     g_return_val_if_fail (etr, FALSE);
 
-    if (track->artwork->thumbnails)
+    if (itdb_track_has_thumbnails (track))
 	changed = TRUE;
 
     itdb_track_remove_thumbnails (track);
@@ -509,6 +518,9 @@ void gp_replace_itdb (iTunesDB *old_itdb, iTunesDB *new_itdb)
     /* Set prefs system with name of MPL */
     mpl = itdb_playlist_mpl (new_itdb);
     set_itdb_prefs_string (new_itdb, "name", mpl->name);
+
+    /* Clean up */
+    g_free (old_pl_name);
 }    
 
 
@@ -519,7 +531,7 @@ void gp_playlist_add (iTunesDB *itdb, Playlist *pl, gint32 pos)
     g_return_if_fail (pl);
 
     itdb_playlist_add (itdb, pl, pos);
-    pm_add_playlist (pl, pos);
+    pm_add_child (itdb, PM_COLUMN_PLAYLIST, pl, pos);
     data_changed (itdb);
 }
 
@@ -535,7 +547,7 @@ Playlist *gp_playlist_add_new (iTunesDB *itdb, gchar *name,
 
     pl = gp_playlist_new (name, spl);
     itdb_playlist_add (itdb, pl, pos);
-    pm_add_playlist (pl, pos);
+    pm_add_child (itdb, PM_COLUMN_PLAYLIST, pl, pos);
     data_changed (itdb);
     return pl;
 }
@@ -814,6 +826,7 @@ void gp_track_validate_entries (Track *track)
     if (!etr->pc_path_locale)    etr->pc_path_locale = g_strdup ("");
     if (!etr->thumb_path_utf8)   etr->thumb_path_utf8 = g_strdup ("");
     if (!etr->thumb_path_locale) etr->thumb_path_locale = g_strdup ("");
+    if (!etr->lyrics)            etr->lyrics = g_strdup ("");
     /* Make sure year_str is identical to year */
     g_free (etr->year_str);
     etr->year_str = g_strdup_printf ("%d", track->year);
@@ -855,7 +868,7 @@ void init_data (GtkWidget *window)
 	/* Local database */
 	filename = g_build_filename (cfgdir, "local_0.itdb", NULL);
 	prefs_set_int ("itdb_0_type", GP_ITDB_TYPE_LOCAL);
-	prefs_set_string ("itdb_0_name", _("Local"));
+	prefs_set_string ("itdb_0_name", _("Music Library"));
 	prefs_set_string ("itdb_0_filename", filename);
 	g_free (filename);
 
@@ -906,6 +919,7 @@ void init_data (GtkWidget *window)
     }
 
     g_free (cfgdir);
+	pm_show_all_playlists ();
 }
 
 
@@ -1095,17 +1109,7 @@ gboolean gp_increase_playcount (gchar *sha1, gchar *file, gint num)
  * returned if no itdb is active. */
 iTunesDB *gp_get_selected_itdb (void)
 {
-    Playlist *pl = pm_get_selected_playlist ();
-
-    /* If playlist is selected, use the itdb of the playlist as the
-       active itdb */
-    if (pl)
-    {
-	g_return_val_if_fail (pl->itdb, NULL);
-	return pl->itdb;
-    }
-
-    return NULL;
+    return pm_get_selected_itdb ();
 }
 
 
