@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_playlists.c 1776 2007-11-12 22:38:00Z phantom_sf $
+|  $Id: display_playlists.c 2084 2008-08-03 02:59:01Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -47,6 +47,8 @@
 static GtkTreeView *playlist_treeview = NULL;
 /* pointer to the currently selected playlist */
 static Playlist *current_playlist = NULL;
+/* pointer to the currently selected itdb */
+static iTunesDB *current_itdb = NULL;
 /* flag set if selection changes to be ignored temporarily */
 static gboolean pm_selection_blocked = FALSE;
 
@@ -187,8 +189,10 @@ static gboolean pm_drag_motion (GtkWidget *widget,
     GtkTreeViewDropPosition pos;
     GdkAtom target;
     guint info;
+    PM_column_type type;
     Playlist *pl_d;
     iTunesDB *itdb;
+    PhotoDB *photodb;
     ExtraiTunesDBData *eitdb;
 
     g_return_val_if_fail (widget, FALSE);
@@ -214,10 +218,13 @@ static gboolean pm_drag_motion (GtkWidget *widget,
 
     if(gtk_tree_model_get_iter (model, &iter_d, path))
     {
-	gtk_tree_model_get (model, &iter_d, PM_COLUMN_PLAYLIST, &pl_d, -1);
+	gtk_tree_model_get (model, &iter_d,
+			    PM_COLUMN_TYPE, &type,
+			    PM_COLUMN_ITDB, &itdb,
+			    PM_COLUMN_PLAYLIST, &pl_d,
+			    PM_COLUMN_PHOTOS, &photodb,
+			    -1);
     }
-    g_return_val_if_fail (pl_d, FALSE);
-    itdb = pl_d->itdb;
     g_return_val_if_fail (itdb, FALSE);
     eitdb = itdb->userdata;
     g_return_val_if_fail (eitdb, FALSE);
@@ -260,41 +267,55 @@ static gboolean pm_drag_motion (GtkWidget *widget,
 	return FALSE;
     }
 
-    switch (info)
+    switch (type)
     {
-    case DND_GTKPOD_PLAYLISTLIST:
-	/* need to consult drag data to decide */
-	g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_path", path);
-	g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_pos", (gpointer)pos);
-	gtk_drag_get_data (widget, dc, target, time);
-	return TRUE;
-    case DND_GTKPOD_TRACKLIST:
-	/* do not allow drop into currently selected playlist */
-	if (pl_d == pm_get_selected_playlist ())
+    case PM_COLUMN_PLAYLIST:
+	switch (info)
 	{
-	    if ((pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE) ||
-		(pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER))
+	case DND_GTKPOD_PLAYLISTLIST:
+	    /* need to consult drag data to decide */
+	    g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_path", path);
+	    g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_pos", (gpointer)pos);
+	    gtk_drag_get_data (widget, dc, target, time);
+	    return TRUE;
+	case DND_GTKPOD_TRACKLIST:
+	    /* do not allow drop into currently selected playlist */
+	    if (pl_d == pm_get_selected_playlist ())
 	    {
-		gtk_tree_path_free (path);
-		gdk_drag_status (dc, 0, time);
-		return FALSE;
+		if ((pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE) ||
+		    (pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER))
+		{
+		    gtk_tree_path_free (path);
+		    gdk_drag_status (dc, 0, time);
+		    return FALSE;
+		}
 	    }
+	    /* need to consult drag data to decide */
+	    g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_path", path);
+	    g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_pos", (gpointer)pos);
+	    gtk_drag_get_data (widget, dc, target, time);
+	    return TRUE;
+	case DND_TEXT_PLAIN:
+	case DND_TEXT_URI_LIST:
+	    gdk_drag_status (dc, dc->suggested_action, time);
+	    gtk_tree_path_free (path);
+	    return TRUE;
+	default:
+	    g_warning ("Programming error: pm_drag_motion received unknown info type (%d)\n", info);
+	    gtk_tree_path_free (path);
+	    return FALSE;
 	}
-	/* need to consult drag data to decide */
-	g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_path", path);
-	g_object_set_data (G_OBJECT (widget), "drag_data_by_motion_pos", (gpointer)pos);
-	gtk_drag_get_data (widget, dc, target, time);
-	return TRUE;
-    case DND_TEXT_PLAIN:
-    case DND_TEXT_URI_LIST:
-	gdk_drag_status (dc, dc->suggested_action, time);
-	gtk_tree_path_free (path);
-	return TRUE;
-    default:
-	g_warning ("Programming error: pm_drag_motion received unknown info type (%d)\n", info);
-	gtk_tree_path_free (path);
+	g_return_val_if_reached (FALSE);
+
+    case PM_COLUMN_PHOTOS:
+	/* We don't handle drops into the photo playlist yet */
 	return FALSE;
+    case PM_NUM_COLUMNS:
+    case PM_COLUMN_ITDB:
+    case PM_COLUMN_TYPE:
+	g_return_val_if_reached (FALSE);
     }
+    g_return_val_if_reached (FALSE);
 }
 
 
@@ -1071,7 +1092,7 @@ static gboolean pm_get_iter_for_playlist (Playlist *playlist, GtkTreeIter *pl_it
 	gtk_tree_model_get (model, &itdb_iter,
 			    PM_COLUMN_PLAYLIST, &pl,
 			    -1);
-	g_return_val_if_fail (pl, FALSE);
+
 	if (pl == playlist)
 	{
 	    *pl_iter = itdb_iter;
@@ -1090,7 +1111,7 @@ static gboolean pm_get_iter_for_playlist (Playlist *playlist, GtkTreeIter *pl_it
 	    gtk_tree_model_get (model, pl_iter,
 				PM_COLUMN_PLAYLIST, &pl,
 				-1);
-	    g_return_val_if_fail (pl, FALSE);
+
 	    if (pl == playlist)
 	    {
 		return TRUE;
@@ -1187,49 +1208,87 @@ void pm_track_changed (Track *track)
 /* If @position = -1: append to end */
 /* If @position >=0: insert at that position (count starts with MPL as
  * 0) */
-void pm_add_playlist (Playlist *playlist, gint pos)
+void pm_add_child (iTunesDB *itdb, PM_column_type type, gpointer item, gint pos)
 {
   GtkTreeIter mpl_iter;
-  GtkTreeIter *mpl = NULL;
+  GtkTreeIter *mpli = NULL;
   GtkTreeIter iter;
   GtkTreeModel *model;
-  GtkTreeSelection *selection;
-  iTunesDB *itdb;
+/*  GtkTreeSelection *selection;*/
 
   g_return_if_fail (playlist_treeview);
-  g_return_if_fail (playlist);
+  g_return_if_fail (item);
+  g_return_if_fail (itdb);
 
   model = GTK_TREE_MODEL (gtk_tree_view_get_model (playlist_treeview));
   g_return_if_fail (model);
 
-  if (itdb_playlist_is_mpl (playlist))
-  {   /* MPLs are always added top-level */
-      mpl = NULL;
-      itdb = playlist->itdb;
-  }
-  else
-  {   /* We need to find the iter with the mpl in it */
-      if (pm_get_iter_for_itdb (playlist->itdb, &mpl_iter))
-      {
-	  mpl = &mpl_iter;
-      }
-      else
-      {
-	  g_warning ("Programming error: need to add mpl before adding normal playlists.\n");
-      }
-      /* reduce position by one because the MPL is not included in the
-	 tree model's count */
-      --pos;
-      itdb = NULL;
+  /* Find the iter with the mpl in it */
+  if (pm_get_iter_for_itdb (itdb, &mpl_iter))
+  {
+      mpli = &mpl_iter;
   }
 
-  gtk_tree_store_insert (GTK_TREE_STORE (model), &iter, mpl, pos);
+  switch (type)
+  {
+  case PM_COLUMN_PLAYLIST:
+      if (itdb_playlist_is_mpl ((Playlist *)item))
+      {   /* MPLs are always added top-level */
+	  mpli = NULL;
+      }
+      else
+      {   /* Handle normal playlist */
+	  /* MPL must be set before calling this function */
+	  g_return_if_fail (mpli);
+	  if (pos == -1)
+	  {   /* just adding at the end will add behind the photo
+	       * item. Find out how many playlists there are and add
+	       * at the end. */
+	      GtkTreeIter pl_iter;
+	      Playlist *pl;
+	      pos = 0;
+	      	/* go down one hierarchy and try all other iters */
+	      if (gtk_tree_model_iter_children (model, &pl_iter, &mpl_iter))
+	      {
+		  do
+		  {
+		      gtk_tree_model_get (model, &pl_iter,
+					  PM_COLUMN_PLAYLIST, &pl,
+					  -1);
+		      if (pl != NULL)
+		      {
+			  ++pos;
+		      }
+		  } while (pl && gtk_tree_model_iter_next (model, &pl_iter));
+	      }
+	  }
+	  else
+	  {   /* reduce position by one because the MPL is not included in the
+		 tree model's count */
+	      --pos;
+	  }
+      }
+      break;
+  case PM_COLUMN_PHOTOS:
+      /* MPL must be set before calling this function */
+      g_return_if_fail (mpli);
+      /* always add at the end */
+      pos = -1;
+      break;
+  case PM_COLUMN_ITDB:
+  case PM_COLUMN_TYPE:
+  case PM_NUM_COLUMNS:
+      g_return_if_reached ();
+  }
+  gtk_tree_store_insert (GTK_TREE_STORE (model), &iter, mpli, pos);
 
   gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
 		      PM_COLUMN_ITDB, itdb,
-		      PM_COLUMN_PLAYLIST, playlist,
+		      PM_COLUMN_TYPE, type,
+		      type, item,
 		      -1);
 
+#if 0
   /* If the current_playlist is "playlist", we select it. This can
      happen during a display_reset */
   if (current_playlist == playlist)
@@ -1237,17 +1296,15 @@ void pm_add_playlist (Playlist *playlist, gint pos)
       selection = gtk_tree_view_get_selection (playlist_treeview);
       gtk_tree_selection_select_iter (selection, &iter);
   }
-  else if (current_playlist == NULL)
+#endif
+/*  else if (current_playlist == NULL)
   {
-      /* If it's the first playlist (no playlist selected AND playlist is
-	 the MPL, we select it, unless prefs_get_mpl_autoselect() says
-	 otherwise */
       if (itdb_playlist_is_mpl(playlist) && prefs_get_int("mpl_autoselect"))
       {
 	  selection = gtk_tree_view_get_selection (playlist_treeview);
 	  gtk_tree_selection_select_iter (selection, &iter);
       }
-  }
+  } */
 }
 
 
@@ -1269,12 +1326,12 @@ void pm_remove_playlist (Playlist *playlist, gboolean select)
 
   ts = gtk_tree_view_get_selection (playlist_treeview);
 
-  if (itdb_playlist_is_mpl (playlist) && current_playlist &&
-      (playlist->itdb == current_playlist->itdb))
+  if (itdb_playlist_is_mpl (playlist) && (playlist->itdb == current_itdb))
   {   /* We are about to remove the entire itdb (playlist is MPL) and
        * a playlist of this itdb is selected --> clear display
        * (pm_unselect_playlist probably works as well, but the
        * unselect won't be done until later (callback)) */
+      gphoto_change_to_photo_window (FALSE);
       st_init (-1, 0);
       current_playlist = NULL;
   }
@@ -1379,14 +1436,13 @@ void pm_unselect_playlist (Playlist *playlist)
 static void pm_selection_changed_cb (GtkTreeSelection *selection,
 				     gpointer user_data2)
 {
-  GtkTreeModel *model;
-  GtkTreeIter  iter;
-  Playlist *new_playlist = NULL;
+	GtkTreeModel *model;
+	GtkTreeIter  iter;
 
 #if DEBUG_TIMING
-  GTimeVal time;
-  g_get_current_time (&time);
-  printf ("pm_selection_changed_cb enter: %ld.%06ld sec\n",
+	GTimeVal time;
+	g_get_current_time (&time);
+	printf ("pm_selection_changed_cb enter: %ld.%06ld sec\n",
 	  time.tv_sec % 3600, time.tv_usec);
 #endif
 
@@ -1394,77 +1450,106 @@ static void pm_selection_changed_cb (GtkTreeSelection *selection,
 	 * in playlist
 	 */
 	 coverart_block_change (TRUE);
-  
-  if (gtk_tree_selection_get_selected (selection, &model, &iter) == FALSE)
-  {  /* no selection -> reset sort tabs */
-      st_init (-1, 0);
-      current_playlist = NULL;
-  }
-  else
-  {   /* handle new selection */
-      gtk_tree_model_get (model, &iter, 
-			  PM_COLUMN_PLAYLIST, &new_playlist,
-			  -1);
 
-      /* If new playlist is in an iPod itdb, set the mountpoint for
-       * the free space display to this iPod (there may be several
-       * iPods connected */
-      g_return_if_fail (new_playlist);
-      g_return_if_fail (new_playlist->itdb);
-      if (new_playlist->itdb->usertype & GP_ITDB_TYPE_IPOD)
-      {
-	  space_set_ipod_itdb (new_playlist->itdb);
-      }
-      
-      if (gphoto_is_photo_playlist (new_playlist))
-      {
-				/* This is the photo playlist so need to load photo database
-      * rather than get tracks.
-				*/
-				gphoto_display_photo_window (new_playlist->itdb);
-      }
-      else
-      {
-				gphoto_change_to_photo_window (FALSE);
-      }
+	if (gtk_tree_selection_get_selected (selection, &model, &iter) == FALSE)
+	{  /* no selection -> reset sort tabs */
+		gphoto_change_to_photo_window (FALSE);
+		st_init (-1, 0);
+		current_playlist = NULL;
+		current_itdb = NULL;
+	}
+	else
+	{
+	    Playlist *new_playlist = NULL;
+	    iTunesDB *itdb = NULL;
+	    PhotoDB *photodb = NULL;
+	    PM_column_type type=0;
+	    gchar *label_text;
+	    /* handle new selection */
+	    gtk_tree_model_get (model, &iter, 
+				PM_COLUMN_TYPE, &type,
+				PM_COLUMN_ITDB, &itdb,
+				PM_COLUMN_PLAYLIST, &new_playlist,
+				PM_COLUMN_PHOTOS, &photodb,
+				-1);
 
-      /* remove all entries from sort tab 0 */
-      /* printf ("removing entries: %x\n", current_playlist);*/
-      st_init (-1, 0);
+	    current_playlist = new_playlist;
+	    current_itdb = itdb;
 
-     current_playlist = new_playlist;
-      if (new_playlist->is_spl && new_playlist->splpref.liveupdate)
-	  itdb_spl_update (new_playlist);
-      if (new_playlist->members)
-      {
-	  GList *gl;
+	    switch (type)
+	    {
+	    case PM_COLUMN_PLAYLIST:
+		g_return_if_fail (new_playlist);
+		g_return_if_fail (itdb);
 
-	  st_enable_disable_view_sort (0, FALSE);
-	  for (gl=new_playlist->members; gl; gl=gl->next)
-	  { /* add all tracks to sort tab 0 */
-	      Track *track = gl->data;
-	      st_add_track (track, FALSE, TRUE, 0);
-	  }
-	  st_enable_disable_view_sort (0, TRUE);
-	  st_add_track (NULL, TRUE, TRUE, 0);
-      }
-      gtkpod_tracks_statusbar_update();
-  }
-  
-  /* Reallow the coverart selection update */
-  coverart_block_change (FALSE);
-  /* Set the coverart display based on the selected playlist */
-  coverart_set_images(TRUE);
+		gphoto_change_to_photo_window (FALSE);
+
+		/* If new playlist is in an iPod itdb, set the mountpoint for
+		 * the free space display to this iPod (there may be several
+		 * iPods connected */
+		label_text = g_markup_printf_escaped ("<span weight='bold' size='larger'>%s</span>",
+						      new_playlist->name);
+		gtk_label_set_markup (GTK_LABEL (gtkpod_xml_get_widget (
+						     main_window_xml, "current_playlist_label")),
+				      label_text);
+		g_free (label_text);
+
+		if (itdb->usertype & GP_ITDB_TYPE_IPOD)
+		{
+		    space_set_ipod_itdb (itdb);
+		}
+
+		/* remove all entries from sort tab 0 */
+		/* printf ("removing entries: %x\n", current_playlist);*/
+		st_init (-1, 0);
+
+		if (new_playlist->is_spl && new_playlist->splpref.liveupdate)
+		    itdb_spl_update (new_playlist);
+
+		if (new_playlist->members)
+		{
+		    GList *gl;
+
+		    st_enable_disable_view_sort (0, FALSE);
+
+		    for (gl=new_playlist->members; gl; gl=gl->next)
+		    {
+			/* add all tracks to sort tab 0 */
+			Track *track = gl->data;
+			st_add_track (track, FALSE, TRUE, 0);
+		    }
+
+		    st_enable_disable_view_sort (0, TRUE);
+		    st_add_track (NULL, TRUE, TRUE, 0);
+		}
+		gtkpod_tracks_statusbar_update();
+		break;
+	    case PM_COLUMN_PHOTOS:
+		g_return_if_fail (photodb);
+		g_return_if_fail (itdb);
+		gphoto_display_photo_window (itdb);
+		break;
+	    case PM_COLUMN_ITDB:
+	    case PM_COLUMN_TYPE:
+	    case PM_NUM_COLUMNS:
+		g_warn_if_reached ();
+	    }
+	}
+
+	/* Reallow the coverart selection update */
+	coverart_block_change (FALSE);
+	/* Set the coverart display based on the selected playlist */
+	coverart_display_update(TRUE);
 	 
-  space_data_update ();
-    
+	space_data_update ();
+
 #if DEBUG_TIMING
-  g_get_current_time (&time);
-  printf ("pm_selection_changed_cb exit:  %ld.%06ld sec\n",
-	  time.tv_sec % 3600, time.tv_usec);
+	g_get_current_time (&time);
+	printf ("pm_selection_changed_cb exit:  %ld.%06ld sec\n",
+		time.tv_sec % 3600, time.tv_usec);
 #endif 
-  /* make only suitable delete menu items available */
-  display_adjust_menus ();
+	/* make only suitable delete menu items available */
+	display_adjust_menus ();
 }
 
 /* Callback function called when the selection
@@ -1514,65 +1599,46 @@ static gint pm_sort_counter (gint inc)
 /* Add all playlists of @itdb at position @pos */
 void pm_add_itdb (iTunesDB *itdb, gint pos)
 {
+    GtkTreeIter mpl_iter;
     GList *gl_pl;
+    ExtraiTunesDBData *eitdb;
 
     g_return_if_fail (itdb);
+    eitdb=itdb->userdata;
+    g_return_if_fail (eitdb);
 
     for (gl_pl=itdb->playlists; gl_pl; gl_pl=gl_pl->next)
     {
-			Playlist *pl = gl_pl->data;
-			g_return_if_fail (pl);
-			if (itdb_playlist_is_mpl (pl))     pm_add_playlist (pl, pos);
-			else                               pm_add_playlist (pl, -1);
-    }
-    
-    /* Add the photo playlist onto IPOD itdb if the
-	 * IPOD supports photos
-	 */
-	if (gphoto_ipod_supports_photos (itdb))
-	{   /* add photo playlist */
-/*		printf ("Photos supported. Adding node.\n"); */
-		GtkTreeIter itdb_iter;
-		
-		if (pm_get_iter_for_itdb (itdb, &itdb_iter))
-    {
-			gboolean createpl = TRUE;
-   	GtkTreeIter pl_iter;
-   	GtkTreeModel *model;
-			Playlist *pl;
-
-			model = GTK_TREE_MODEL (gtk_tree_view_get_model (playlist_treeview));
-
-			/* go down one hierarchy and try all other iters */
-			if (gtk_tree_model_iter_children (model, &pl_iter, &itdb_iter))
-			{
-				do
-				{
-	   		gtk_tree_model_get (model, &pl_iter,
-					PM_COLUMN_PLAYLIST, &pl,
-					-1);
-	    		if (pl->type == GP_PL_TYPE_PHOTO)
-	    		{
-	    			/* Photo playlist already found so dont need to readd */
-	    		createpl = FALSE;
-	    			break;
-	    		}
-				} while (gtk_tree_model_iter_next (model, &pl_iter));
-    	}
-    	
-    	if (createpl)
-    	{
-    		/* no existing photo playlist found so add one
-    	 * either itdb had no children or none of them
-    	 * were of the photo type.
-    	 */
-				Playlist *pl = itdb_playlist_new (_("Photos"), FALSE);
-				pl->type = GP_PL_TYPE_PHOTO;
-				pl->itdb = itdb;
-				pm_add_playlist (pl, -1);
-			}
-    }
+	Playlist *pl = gl_pl->data;
+	g_return_if_fail (pl);
+	if (itdb_playlist_is_mpl (pl))
+	{
+	    pm_add_child (itdb, PM_COLUMN_PLAYLIST, pl, pos);
 	}
+	else
+	{
+	    pm_add_child (itdb, PM_COLUMN_PLAYLIST, pl, -1);
+	}
+    }
+    /* eitdb->photodb might be NULL: the itdb is added before the iPod
+     * is parsed */
+    if (itdb_device_supports_photo (itdb->device) && eitdb->photodb)
+    {
+	pm_add_child (itdb, PM_COLUMN_PHOTOS, eitdb->photodb, -1);
+    }
+
+    /* expand the itdb */
+    if (pm_get_iter_for_itdb (itdb, &mpl_iter))
+    {
+	GtkTreeModel *model;
+	GtkTreePath *mpl_path;
+	model = GTK_TREE_MODEL (gtk_tree_view_get_model (playlist_treeview));
+	g_return_if_fail (model);
+	mpl_path = gtk_tree_model_get_path (model, &mpl_iter);
+	g_return_if_fail (mpl_path);
+	gtk_tree_view_expand_row (playlist_treeview, mpl_path, TRUE);
+	gtk_tree_path_free (mpl_path);
+    }
 }
 
 
@@ -1905,130 +1971,169 @@ pm_cell_edited (GtkCellRendererText *renderer,
  * @renderer: renderer to be set
  * @playlist: playlist to consider.
  */
-void pm_set_renderer_text (GtkCellRenderer *renderer,
-			   Playlist *playlist)
+void pm_set_playlist_renderer_text (GtkCellRenderer *renderer,
+				    Playlist *playlist)
 {
-    if (playlist)
-    {
-	ExtraiTunesDBData *eitdb;
+    ExtraiTunesDBData *eitdb;
 
-	g_return_if_fail (playlist->itdb);
-	eitdb = playlist->itdb->userdata;
-	g_return_if_fail (eitdb);
+    g_return_if_fail (playlist);
+    g_return_if_fail (playlist->itdb);
+    eitdb = playlist->itdb->userdata;
+    g_return_if_fail (eitdb);
 
-	if (itdb_playlist_is_mpl (playlist))
-	{   /* mark MPL */
+    if (itdb_playlist_is_mpl (playlist))
+    {   /* mark MPL */
+	g_object_set (G_OBJECT (renderer),
+		      "text", playlist->name, 
+		      "weight", PANGO_WEIGHT_BOLD,
+		      NULL);
+	if (eitdb->data_changed)
+	{
 	    g_object_set (G_OBJECT (renderer),
-			  "text", playlist->name, 
-			  "weight", PANGO_WEIGHT_BOLD,
+			  "style", PANGO_STYLE_ITALIC,
 			  NULL);
-	    if (eitdb->data_changed)
-	    {
-		g_object_set (G_OBJECT (renderer),
-			      "style", PANGO_STYLE_ITALIC,
-			      NULL);
-	    }
-	    else
-	    {
-		g_object_set (G_OBJECT (renderer),
-			      "style", PANGO_STYLE_NORMAL,
-			      NULL);
-	    }
 	}
 	else
 	{
-	    if (itdb_playlist_is_podcasts (playlist))
-	    {
-		g_object_set (G_OBJECT (renderer),
-			      "text", playlist->name, 
-			      "weight", PANGO_WEIGHT_SEMIBOLD,
-			      "style", PANGO_STYLE_ITALIC,
-			      NULL);
-	    }
-	    else
-	    {
-		g_object_set (G_OBJECT (renderer),
-			      "text", playlist->name, 
-			      "weight", PANGO_WEIGHT_NORMAL,
-			      "style", PANGO_STYLE_NORMAL,
-			      NULL);
-	    }
+	    g_object_set (G_OBJECT (renderer),
+			  "style", PANGO_STYLE_NORMAL,
+			  NULL);
 	}
     }
     else
+    {
+	if (itdb_playlist_is_podcasts (playlist))
+	{
+	    g_object_set (G_OBJECT (renderer),
+			  "text", playlist->name, 
+			  "weight", PANGO_WEIGHT_SEMIBOLD,
+			  "style", PANGO_STYLE_ITALIC,
+			  NULL);
+	}
+	else
+	{
+	    g_object_set (G_OBJECT (renderer),
+			  "text", playlist->name, 
+			  "weight", PANGO_WEIGHT_NORMAL,
+			  "style", PANGO_STYLE_NORMAL,
+			  NULL);
+	}
+    }
+}
+
+/**
+ * pm_set_photodb_renderer_text
+ *
+ * Set the PhotoDB name in appropriate style.
+ *
+ * @renderer: renderer to be set
+ * @PhotoDB: photodb to consider.
+ */
+void pm_set_photodb_renderer_text (GtkCellRenderer *renderer,
+				   PhotoDB *photodb)
+{
+    g_return_if_fail (photodb);
+
+    /* bold face */
+    g_object_set (G_OBJECT (renderer),
+		  "text", _("Photos"), 
+		  "weight", PANGO_WEIGHT_BOLD,
+		  NULL);
+/* (example for italic style)
+    if (eitdb->data_changed)
     {
 	g_object_set (G_OBJECT (renderer),
-		      "text", "",
+		      "style", PANGO_STYLE_ITALIC,
 		      NULL);
     }
+    else
+    {
+	g_object_set (G_OBJECT (renderer),
+		      "style", PANGO_STYLE_NORMAL,
+		      NULL);
+    }
+*/
 }
 
 
 /**
- * pm_set_renderer_pix
+ * pm_set_playlist_renderer_pix
  *
  * Set the appropriate playlist icon.
  *
  * @renderer: renderer to be set
  * @playlist: playlist to consider.
  */
-void pm_set_renderer_pix (GtkCellRenderer *renderer,
-			  Playlist *playlist)
+void pm_set_playlist_renderer_pix (GtkCellRenderer *renderer,
+				   Playlist *playlist)
+{
+    iTunesDB *itdb;
+    ExtraiTunesDBData *eitdb;
+
+    const gchar *stock_id=NULL;
+
+    g_return_if_fail (renderer);
+    g_return_if_fail (playlist);
+    g_return_if_fail (playlist->itdb);
+
+    itdb = playlist->itdb;
+    g_return_if_fail (itdb->userdata);
+    eitdb = itdb->userdata;
+
+    if (playlist->is_spl)
+    {
+	stock_id = GTK_STOCK_PROPERTIES;
+    }
+    else if (!itdb_playlist_is_mpl (playlist))
+    {
+	stock_id = TUNES_PLAYLIST_ICON_STOCK_ID;
+    }
+    else
+    {
+	if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
+	{
+	    stock_id = GTK_STOCK_HARDDISK;
+	}
+	else
+	{
+	    if (eitdb->itdb_imported)
+	    {
+		stock_id = GTK_STOCK_CONNECT;
+	    }
+	    else
+	    {
+		stock_id = GTK_STOCK_DISCONNECT;
+	    }
+	}
+    }
+    g_object_set (G_OBJECT (renderer), "stock-id", stock_id, NULL);
+    g_object_set (G_OBJECT (renderer), "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+}
+
+/**
+ * pm_set_photodb_renderer_pix
+ *
+ * Set the appropriate photodb icon.
+ *
+ * @renderer: renderer to be set
+ * @photodb: photodb to consider.
+ */
+void pm_set_photodb_renderer_pix (GtkCellRenderer *renderer,
+				  PhotoDB *photodb)
 {
     const gchar *stock_id=NULL;
 
     g_return_if_fail (renderer);
+    g_return_if_fail (photodb);
 
-    if (playlist)
-    {
-	iTunesDB *itdb;
-	ExtraiTunesDBData *eitdb;
+    stock_id = GPHOTO_PLAYLIST_ICON_STOCK_ID;
 
-	g_return_if_fail (playlist->itdb);
-	itdb = playlist->itdb;
-	g_return_if_fail (itdb->userdata);
-	eitdb = itdb->userdata;
-
-	if (playlist->is_spl)
-	{
-	    stock_id = GTK_STOCK_PROPERTIES;
-	}
-	else if (!itdb_playlist_is_mpl (playlist))
-	{
-		if (gphoto_is_photo_playlist (playlist))
-		{
-			stock_id = GPHOTO_PLAYLIST_ICON_STOCK_ID;
-		}
-		else
-		{
-			stock_id = TUNES_PLAYLIST_ICON_STOCK_ID;
-		}
-	}
-	else
-	{
-	    if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
-	    {
-		stock_id = GTK_STOCK_HARDDISK;
-	    }
-	    else
-	    {
-		if (eitdb->itdb_imported)
-		{
-		    stock_id = GTK_STOCK_CONNECT;
-		}
-		else
-		{
-		    stock_id = GTK_STOCK_DISCONNECT;
-		}
-	    }
-	}
-    }
-
-  g_object_set (G_OBJECT (renderer),
-		"stock-id", stock_id, NULL);
+    g_object_set (G_OBJECT (renderer), "stock-id", stock_id, NULL);
+    g_object_set (G_OBJECT (renderer), "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
 }
 
 
+
 /* The playlist data is stored in a separate list
    and only pointers to the corresponding playlist structure are placed
    into the model.
@@ -2041,15 +2146,31 @@ static void pm_cell_data_func (GtkTreeViewColumn *tree_column,
 			       gpointer           data)
 {
   Playlist *playlist = NULL;
+  PhotoDB *photodb = NULL;
+  PM_column_type type;
 
   g_return_if_fail (renderer);
   g_return_if_fail (model);
   g_return_if_fail (iter);
 
-  gtk_tree_model_get (model, iter, PM_COLUMN_PLAYLIST, &playlist, -1);
-  g_return_if_fail (playlist);
-
-  pm_set_renderer_text (renderer, playlist);
+  gtk_tree_model_get (model, iter,
+		      PM_COLUMN_TYPE, &type,
+		      PM_COLUMN_PLAYLIST, &playlist,
+		      PM_COLUMN_PHOTOS, &photodb,
+		      -1);
+  switch (type)
+  {
+  case PM_COLUMN_PLAYLIST:
+      pm_set_playlist_renderer_text (renderer, playlist);
+      break;
+  case PM_COLUMN_PHOTOS:
+      pm_set_photodb_renderer_text (renderer, photodb);
+      break;
+  case PM_COLUMN_ITDB:
+  case PM_COLUMN_TYPE:
+  case PM_NUM_COLUMNS:
+      g_return_if_reached ();
+  }
 }
 
 
@@ -2060,16 +2181,32 @@ static void pm_cell_data_func_pix (GtkTreeViewColumn *tree_column,
 				   GtkTreeIter       *iter,
 				   gpointer           data)
 {
-  Playlist *playlist=NULL;
+  Playlist *playlist = NULL;
+  PhotoDB *photodb = NULL;
+  PM_column_type type;
 
   g_return_if_fail (renderer);
   g_return_if_fail (model);
   g_return_if_fail (iter);
 
-  gtk_tree_model_get (model, iter, PM_COLUMN_PLAYLIST, &playlist, -1);
-  g_return_if_fail (playlist);
-
-  pm_set_renderer_pix (renderer, playlist);
+  gtk_tree_model_get (model, iter,
+		      PM_COLUMN_TYPE, &type,
+		      PM_COLUMN_PLAYLIST, &playlist,
+		      PM_COLUMN_PHOTOS, &photodb,
+		      -1);
+  switch (type)
+  {
+  case PM_COLUMN_PLAYLIST:
+      pm_set_playlist_renderer_pix (renderer, playlist);
+      break;
+  case PM_COLUMN_PHOTOS:
+      pm_set_photodb_renderer_pix (renderer, photodb);
+      break;
+  case PM_COLUMN_ITDB:
+  case PM_COLUMN_TYPE:
+  case PM_NUM_COLUMNS:
+      g_return_if_reached ();
+  }
 }
 
 
@@ -2214,6 +2351,7 @@ pm_button_press (GtkWidget *w, GdkEventButton *e, gpointer data)
 		 * an iPod */
 		eitdb = pl->itdb->userdata;
 		g_return_val_if_fail (eitdb, FALSE);
+		block_widgets ();
 		if (!eitdb->itdb_imported)
 		{
 		    gp_load_ipod (pl->itdb);
@@ -2222,6 +2360,7 @@ pm_button_press (GtkWidget *w, GdkEventButton *e, gpointer data)
 		{
 		    gp_eject_ipod (pl->itdb);
 		}
+		release_widgets ();
 		return TRUE;
 	    }
 	    if (pl->itdb->usertype & GP_ITDB_TYPE_LOCAL)
@@ -2245,47 +2384,48 @@ pm_button_press (GtkWidget *w, GdkEventButton *e, gpointer data)
 /* Adds the columns to our playlist_treeview */
 static void pm_add_columns (void)
 {
-  GtkTreeViewColumn *column;
-  GtkCellRenderer *renderer;
-  GtkTreeModel *model;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer *renderer;
+	GtkTreeModel *model;
 
-  model = gtk_tree_view_get_model (playlist_treeview);
-  g_return_if_fail (model);
+	model = gtk_tree_view_get_model (playlist_treeview);
+	g_return_if_fail (model);
 
 
-  /* playlist column */
-  column = gtk_tree_view_column_new ();
-  gtk_tree_view_column_set_title (column, _("Playlists"));
-/* FIXME: see comments at pm_data_compare_func() */
-/*
-  gtk_tree_view_column_set_sort_column_id (column, PM_COLUMN_PLAYLIST);
-  gtk_tree_view_column_set_sort_order (column, GTK_SORT_ASCENDING);
-  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+	/* playlist column */
+	column = gtk_tree_view_column_new ();
+	gtk_tree_view_column_set_title (column, _("Playlists"));
+	/* FIXME: see comments at pm_data_compare_func() */
+	/*
+	gtk_tree_view_column_set_sort_column_id (column, PM_COLUMN_PLAYLIST);
+	gtk_tree_view_column_set_sort_order (column, GTK_SORT_ASCENDING);
+	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
 				   PM_COLUMN_PLAYLIST,
 				   pm_data_compare_func, column, NULL);
-  gtk_tree_view_column_set_clickable(column, TRUE);
-  g_signal_connect (G_OBJECT (column), "clicked",
-		    G_CALLBACK (pm_track_column_button_clicked),
+	gtk_tree_view_column_set_clickable(column, TRUE);
+	g_signal_connect (G_OBJECT (column), "clicked",
+			G_CALLBACK (pm_track_column_button_clicked),
 				(gpointer)PM_COLUMN_PLAYLIST);
-*/
-  gtk_tree_view_append_column (playlist_treeview, column);
+	*/
 
-  /* cell for graphic indicator */
-  renderer = gtk_cell_renderer_pixbuf_new ();
+	gtk_tree_view_append_column (playlist_treeview, column);
 
-  gtk_tree_view_column_pack_start (column, renderer, FALSE); 
-  gtk_tree_view_column_set_cell_data_func (column, renderer,
+	/* cell for graphic indicator */
+	renderer = gtk_cell_renderer_pixbuf_new ();
+
+	gtk_tree_view_column_pack_start (column, renderer, FALSE); 
+	gtk_tree_view_column_set_cell_data_func (column, renderer,
 					   pm_cell_data_func_pix,
 					   NULL, NULL);
-  /* cell for playlist name */
-  renderer = gtk_cell_renderer_text_new ();
-  g_signal_connect (G_OBJECT (renderer), "edited",
-		    G_CALLBACK (pm_cell_edited), model);
-  gtk_tree_view_column_pack_start (column, renderer, FALSE);
-  gtk_tree_view_column_set_cell_data_func (column, renderer,
+	/* cell for playlist name */
+	renderer = gtk_cell_renderer_text_new ();
+	g_signal_connect (G_OBJECT (renderer), "edited",
+			G_CALLBACK (pm_cell_edited), model);
+	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	gtk_tree_view_column_set_cell_data_func (column, renderer,
 					   pm_cell_data_func,
 					   NULL, NULL);
-  g_object_set (G_OBJECT (renderer),
+	g_object_set (G_OBJECT (renderer),
 		"editable", TRUE,
 		NULL);
 }
@@ -2294,100 +2434,100 @@ static void pm_add_columns (void)
 /* Create playlist listview */
 void pm_create_treeview (void)
 {
-  GtkTreeStore *model;
-  GtkTreeSelection *selection;
-  GtkWidget *playlist_window;
-  GtkWidget *tree;
+	GtkTreeStore *model;
+	GtkTreeSelection *selection;
+	GtkWidget *playlist_window;
+	GtkWidget *tree;
 
-  playlist_window = gtkpod_xml_get_widget (main_window_xml, "playlist_window");
-  g_return_if_fail (playlist_window);
+	playlist_window = gtkpod_xml_get_widget (main_window_xml, "playlist_window");
+	g_return_if_fail (playlist_window);
 
-  /* destroy old treeview */
-  if (playlist_treeview)
-  {
-      model = GTK_TREE_STORE (gtk_tree_view_get_model(playlist_treeview));
-      g_return_if_fail (model);
-      g_object_unref (model);
-      gtk_widget_destroy (GTK_WIDGET (playlist_treeview));
-      playlist_treeview = NULL;
-  }
-  /* create new one */
-  tree = gtk_tree_view_new ();
-  gtk_widget_set_events (tree, GDK_KEY_RELEASE_MASK);
-  gtk_widget_show (tree);
-  playlist_treeview = GTK_TREE_VIEW (tree);
-  gtk_container_add (GTK_CONTAINER (playlist_window), tree);
+	/* destroy old treeview */
+	if (playlist_treeview)
+	{
+	  model = GTK_TREE_STORE (gtk_tree_view_get_model(playlist_treeview));
+	  g_return_if_fail (model);
+	  g_object_unref (model);
+	  gtk_widget_destroy (GTK_WIDGET (playlist_treeview));
+	  playlist_treeview = NULL;
+	}
+	/* create new one */
+	tree = gtk_tree_view_new ();
+	gtk_widget_set_events (tree, GDK_KEY_RELEASE_MASK);
+	gtk_widget_show (tree);
+	playlist_treeview = GTK_TREE_VIEW (tree);
+	gtk_container_add (GTK_CONTAINER (playlist_window), tree);
 
-  /* create model */
-  model =   gtk_tree_store_new (PM_NUM_COLUMNS, G_TYPE_POINTER, G_TYPE_POINTER);
+	/* create model */
+	model =   gtk_tree_store_new (PM_NUM_COLUMNS, G_TYPE_POINTER, G_TYPE_INT, G_TYPE_POINTER, G_TYPE_POINTER);
 
-  /* set tree model */
-  gtk_tree_view_set_model (playlist_treeview, GTK_TREE_MODEL (model));
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (playlist_treeview), TRUE);
-  gtk_tree_selection_set_mode (gtk_tree_view_get_selection (playlist_treeview),
-			       GTK_SELECTION_SINGLE);
-  selection = gtk_tree_view_get_selection (playlist_treeview);
-  g_signal_connect (G_OBJECT (selection), "changed",
-		    G_CALLBACK (pm_selection_changed), NULL);
-  pm_add_columns ();
+	/* set tree model */
+	gtk_tree_view_set_model (playlist_treeview, GTK_TREE_MODEL (model));
+	/* gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (playlist_treeview), TRUE); */
+	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (playlist_treeview),
+				   GTK_SELECTION_SINGLE);
+	selection = gtk_tree_view_get_selection (playlist_treeview);
+	g_signal_connect (G_OBJECT (selection), "changed",
+			G_CALLBACK (pm_selection_changed), NULL);
+	pm_add_columns ();
 
-  gtk_drag_source_set (GTK_WIDGET (playlist_treeview),
-		       GDK_BUTTON1_MASK,
-		       pm_drag_types, TGNR (pm_drag_types),
-		       GDK_ACTION_COPY|GDK_ACTION_MOVE);
-  gtk_drag_dest_set (GTK_WIDGET (playlist_treeview),
-		     GTK_DEST_DEFAULT_HIGHLIGHT,
-		     pm_drop_types, TGNR (pm_drop_types),
-		     GDK_ACTION_COPY|GDK_ACTION_MOVE);
+	gtk_drag_source_set (GTK_WIDGET (playlist_treeview),
+			   GDK_BUTTON1_MASK,
+			   pm_drag_types, TGNR (pm_drag_types),
+			   GDK_ACTION_COPY|GDK_ACTION_MOVE);
+	gtk_drag_dest_set (GTK_WIDGET (playlist_treeview),
+			 GTK_DEST_DEFAULT_HIGHLIGHT,
+			 pm_drop_types, TGNR (pm_drop_types),
+			 GDK_ACTION_COPY|GDK_ACTION_MOVE);
 
 
-/*   gtk_tree_view_enable_model_drag_dest (playlist_treeview, */
-/* 					pm_drop_types, TGNR (pm_drop_types), */
-/* 					GDK_ACTION_COPY); */
-  /* need the gtk_drag_dest_set() with no actions ("0") so that the
-     data_received callback gets the correct info value. This is most
-     likely a bug... */
-/*   gtk_drag_dest_set_target_list (GTK_WIDGET (playlist_treeview), */
-/* 				 gtk_target_list_new (pm_drop_types, */
-/* 						      TGNR (pm_drop_types))); */
+	/*   gtk_tree_view_enable_model_drag_dest (playlist_treeview, */
+	/* 					pm_drop_types, TGNR (pm_drop_types), */
+	/* 					GDK_ACTION_COPY); */
+	/* need the gtk_drag_dest_set() with no actions ("0") so that the
+	 data_received callback gets the correct info value. This is most
+	 likely a bug... */
+	/*   gtk_drag_dest_set_target_list (GTK_WIDGET (playlist_treeview), */
+	/* 				 gtk_target_list_new (pm_drop_types, */
+	/* 						      TGNR (pm_drop_types))); */
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-begin",
-		    G_CALLBACK (pm_drag_begin),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-begin",
+			G_CALLBACK (pm_drag_begin),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-data-delete",
-		    G_CALLBACK (pm_drag_data_delete),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-data-delete",
+			G_CALLBACK (pm_drag_data_delete),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-data-get",
-		    G_CALLBACK (pm_drag_data_get),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-data-get",
+			G_CALLBACK (pm_drag_data_get),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-data-received",
-		    G_CALLBACK (pm_drag_data_received),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-data-received",
+			G_CALLBACK (pm_drag_data_received),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-drop",
-		    G_CALLBACK (pm_drag_drop),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-drop",
+			G_CALLBACK (pm_drag_drop),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-end",
-		    G_CALLBACK (pm_drag_end),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-end",
+			G_CALLBACK (pm_drag_end),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-leave",
-		    G_CALLBACK (pm_drag_leave),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-leave",
+			G_CALLBACK (pm_drag_leave),
+			NULL);
 
-  g_signal_connect ((gpointer) playlist_treeview, "drag-motion",
-		    G_CALLBACK (pm_drag_motion),
-		    NULL);
+	g_signal_connect ((gpointer) playlist_treeview, "drag-motion",
+			G_CALLBACK (pm_drag_motion),
+			NULL);
 
-  g_signal_connect_after ((gpointer) playlist_treeview, "key_release_event",
+	g_signal_connect_after ((gpointer) playlist_treeview, "key_release_event",
 			  G_CALLBACK (on_playlist_treeview_key_release_event),
 			  NULL);
-  g_signal_connect (G_OBJECT (playlist_treeview), "button-press-event",
-		    G_CALLBACK (pm_button_press), model);
+	g_signal_connect (G_OBJECT (playlist_treeview), "button-press-event",
+			G_CALLBACK (pm_button_press), model);
 }
 
 
@@ -2420,9 +2560,42 @@ pm_get_selected_playlist (void)
     return result;
 }
 
+iTunesDB*
+pm_get_selected_itdb (void)
+{
+/* return(current_playlist);*/
+/* we can't just return the "current_playlist" because the context
+   menus require the selection before "current_playlist" is updated */
+
+    GtkTreeSelection *ts;
+    GtkTreeIter iter;
+    GtkTreeModel *model;
+    iTunesDB *result = NULL;
+
+    g_return_val_if_fail (playlist_treeview, NULL);
+    ts = gtk_tree_view_get_selection (playlist_treeview);
+    g_return_val_if_fail (ts, NULL);
+
+    if (gtk_tree_selection_get_selected (ts, &model, &iter))
+    {
+	gtk_tree_model_get (model, &iter,
+			    PM_COLUMN_ITDB, &result, -1);
+    }
+
+    /* playlist was just changed -- wait until current_playlist is
+       updated. */
+    if (result != current_itdb)  result=NULL;
+    return result;
+}
+
 /* use with care!! */
 void
 pm_set_selected_playlist (Playlist *pl)
 {
     current_playlist = pl;
 }
+
+void pm_show_all_playlists ()
+{
+	gtk_tree_view_expand_all (playlist_treeview);
+}
