@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: file.c 1824 2007-12-13 10:51:04Z dforsi $
+|  $Id: file.c 2185 2008-12-31 22:30:36Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -37,6 +37,8 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <glib.h>
+#include <glib/gstdio.h>
 
 
 #include "charset.h"
@@ -823,10 +825,10 @@ static gboolean copy_new_info (Track *from, Track *to)
 	case T_SORT_TVSHOW:
 	case T_YEAR:
 	case T_TRACK_NR:
-	case T_SIZE:
 	case T_TRACKLEN:
 	case T_STARTTIME:
 	case T_STOPTIME:
+	case T_SIZE:
 	case T_BITRATE:
 	case T_SAMPLERATE:
 	case T_BPM:
@@ -840,6 +842,7 @@ static gboolean copy_new_info (Track *from, Track *to)
 	case T_SEASON_NR:
 	case T_EPISODE_NR:
 	case T_GROUPING:
+	case T_LYRICS:
 	    changed |= track_copy_item (from, to, item);
 	    break;
 	case T_CATEGORY:
@@ -871,6 +874,13 @@ static gboolean copy_new_info (Track *from, Track *to)
 	changed = TRUE;
     }
 
+    if (from->chapterdata)
+    {
+	itdb_chapterdata_free (to->chapterdata);
+	to->chapterdata = itdb_chapterdata_duplicate (from->chapterdata);
+	changed = TRUE; /* FIXME: probably should actually compare chapters for changes */
+    }
+
     itdb_artwork_free (to->artwork);
     to->artwork = itdb_artwork_duplicate (from->artwork);
     if ((to->artwork_size != from->artwork_size) ||
@@ -905,6 +915,12 @@ static gboolean copy_new_info (Track *from, Track *to)
 	to->gapless_track_flag = from->gapless_track_flag;
     }
 
+    if (eto->mtime != efrom->mtime)
+    {
+	changed = TRUE;
+	eto->mtime = efrom->mtime;
+    }
+
     return changed;
 }
 
@@ -1010,7 +1026,126 @@ gboolean update_mserv_data_from_file (gchar *name, Track *track)
     return success;
 }
 
+/* ensure that a cache directory is available for video thumbnail generation.
+ * largely copied from conversion_setup_cachedir, only slightly simplified
+ * and modified to return the path to the caller for convenience.
+ */
+static gchar* video_thumbnail_setup_cache() 
+{
+	gchar *cachedir = NULL;
+	gchar *cfgdir = prefs_get_cfgdir();
 
+	if (!cfgdir)
+        return NULL;
+    
+    cachedir = g_build_filename (cfgdir, "video_thumbnail_cache", NULL);
+    g_free (cfgdir);
+
+    if (!g_file_test (cachedir, G_FILE_TEST_IS_DIR) && (g_mkdir (cachedir, 0777) == -1))
+    {
+        gtkpod_warning (_("Could not create '%s'"), cachedir);
+	g_free (cachedir);
+	cachedir = NULL;
+    }
+
+    return cachedir;
+}
+
+/*
+ * automatically generate a thumbnail for video input files using
+ * an external program (the totem thumbnailer by default).
+ * @input is the path of the video file to be thumbnailed.
+ * Returns a path to a temporary file containing the thumbnail.  The
+ * temporary file is stored in a dedicated cache directory.
+ */
+static gchar* create_video_thumbnail (gchar* input)
+{
+	GString *cmd = NULL;
+	GError *err = NULL;
+	int fd, retval, forkstatus;
+	gchar *thumbnailer = NULL, *tmp_fn = NULL, *tmp = NULL, *p = NULL;
+	/* find (and set up if necessary) the thumbnail cache dir */
+    gchar *tdir = video_thumbnail_setup_cache();
+
+	if (!tdir)
+	{
+		return NULL;
+	}
+    
+	/* safely generate a temporary file.  we don't actually need the fd
+	 * so we close it on succesful generation */
+	tmp_fn = g_build_filename (tdir, "thumb.XXXXXX", NULL);
+	g_free(tdir);
+	tdir = NULL;
+
+	if ((fd = g_mkstemp(tmp_fn)) == -1 || close(fd))
+	{
+		gtkpod_warning (_("Error creating thumbnail file"));
+		g_free (tmp_fn);
+		return NULL;
+	}
+    
+	/* get the string containing the (template) command for thumbnailing */
+	thumbnailer = prefs_get_string("video_thumbnailer_prog");
+	/* copy it into cmd, expanding any format characters */
+	cmd = g_string_new("");
+	p = thumbnailer;
+    
+	while (*p)
+    {
+		if (*p == '%') 
+		{
+			++p;
+            
+			switch (*p)
+            {
+			/* %f: input file */
+			case 'f':
+				tmp = g_shell_quote(input);
+				break;
+			/* %o: temporary output file */
+			case 'o':
+				tmp = g_shell_quote(tmp_fn);
+				break;
+			case '%':
+				cmd = g_string_append_c (cmd, '%');
+				break;
+			default:
+				gtkpod_warning (_("Unknown token '%%%c' in template '%s'"),
+			                    *p, thumbnailer);
+				break;
+			}
+            
+			if (tmp)
+			{
+				cmd = g_string_append (cmd, tmp);
+				g_free (tmp);
+				tmp = NULL;
+			}
+		}
+		else
+		{
+			cmd = g_string_append_c (cmd, *p);
+		}
+        
+		++p;
+	}
+	/* run the thumbnailing program */
+	forkstatus = g_spawn_command_line_sync(cmd->str, NULL, NULL, &retval, &err);
+    
+	if(!forkstatus)
+	{
+		gtkpod_warning (_("Unable to start video thumbnail generator\n(command line was: '%s')"), cmd->str);
+	} 
+	else if(retval)
+	{
+		gtkpod_warning (_("Thumbnail generator returned status %d"), retval);
+	}
+    
+	g_string_free(cmd, TRUE);
+	/* thumbnail is in tmp_fn */
+	return tmp_fn;
+}
 
 /* look for a picture specified by coverart_template  */
 static void add_coverart (Track *tr)
@@ -1020,14 +1155,18 @@ static void add_coverart (Track *tr)
     gchar **templates, **tplp;
     gchar *dirname;
     gchar *filename_local = NULL;
+    FileType type;
+    gint vid_thumbnailer;
 
     g_return_if_fail (tr);
     etr = tr->userdata;
     g_return_if_fail (etr);
 
     dirname = g_path_get_dirname (etr->pc_path_utf8);
+    type = determine_file_type(etr->pc_path_utf8);
 
     full_template = prefs_get_string("coverart_template");
+    vid_thumbnailer = prefs_get_int("video_thumbnailer");
 
     templates = g_strsplit (full_template, ";", 0);
     tplp = templates;
@@ -1039,7 +1178,10 @@ static void add_coverart (Track *tr)
 	{
 	    if (strchr (*tplp, '.') != NULL)
 	    {   /* if template has an extension, try if it is valid */
-		filename_utf8 = g_build_filename (dirname, fname, NULL);
+		if (fname[0] == '/')  /* allow absolute paths in template */
+		    filename_utf8 = g_build_filename ("", fname, NULL);
+		else
+		    filename_utf8 = g_build_filename (dirname, fname, NULL);
 		filename_local = charset_from_utf8 (filename_utf8);
 		g_free (filename_utf8);
 		if (!g_file_test (filename_local, G_FILE_TEST_EXISTS))
@@ -1054,7 +1196,11 @@ static void add_coverart (Track *tr)
 		while (*extp && !filename_local)
 		{
 		    gchar *ffname = g_strconcat (fname, *extp, NULL);
-		    filename_utf8 = g_build_filename (dirname, ffname, NULL);
+		    if (ffname[0] == '/')  /* allow absolute paths in template */
+			filename_utf8 = g_build_filename ("", ffname, NULL);
+		    else
+			filename_utf8 = g_build_filename (dirname, ffname,
+			    NULL);
 		    g_free (ffname);
 		    filename_local = charset_from_utf8 (filename_utf8);
 		    g_free (filename_utf8);
@@ -1071,7 +1217,11 @@ static void add_coverart (Track *tr)
 		    gchar *upper_ext = g_ascii_strup (*extp, -1);
 		    gchar *ffname = g_strconcat (fname, upper_ext, NULL);
 		    g_free (upper_ext);
-		    filename_utf8 = g_build_filename (dirname, ffname, NULL);
+		    if (ffname[0] == '/')  /* allow absolute paths in template */
+			filename_utf8 = g_build_filename ("", ffname, NULL);
+		    else
+			filename_utf8 = g_build_filename (dirname, ffname,
+			    NULL);
 		    g_free (ffname);
 		    filename_local = charset_from_utf8 (filename_utf8);
 		    g_free (filename_utf8);
@@ -1092,9 +1242,27 @@ static void add_coverart (Track *tr)
     {
 	gp_track_set_thumbnails (tr, filename_local);
     }
+    else if(vid_thumbnailer)
+    {
+        /* if a template match was not made, and we're dealing with a video 
+         * file, generate an arbitrary thumbnail if appropriate */
+        switch(type)
+        {
+            case FILE_TYPE_M4V:
+            case FILE_TYPE_MP4:
+            case FILE_TYPE_MOV:
+            case FILE_TYPE_MPG:
+                filename_local = create_video_thumbnail (etr->pc_path_utf8);
+                gp_track_set_thumbnails (tr, filename_local);
+                break;
+            default:
+                break;
+        }
+    }
 
     g_strfreev (templates);
-    g_free(full_template);
+    g_free (full_template);
+    g_free (dirname);
 }
 
 
@@ -1233,6 +1401,7 @@ static Track *get_track_info_from_file (gchar *name, Track *orig_track)
 	/* set path file information */
 	enti->pc_path_utf8 = charset_to_utf8 (name);
 	enti->pc_path_locale = g_strdup (name);
+	enti->lyrics=NULL;
 	/* set length of file */
 	stat (name, &filestat);
 	nti->size = filestat.st_size; /* get the filesize in bytes */
@@ -1249,7 +1418,7 @@ static Track *get_track_info_from_file (gchar *name, Track *orig_track)
 	if (prefs_get_int("coverart_file"))
 	{
 	    /* APIC data takes precedence */
-	    if (!nti->artwork || !nti->artwork->thumbnails)
+	    if (! itdb_track_has_thumbnails (nti))
 		add_coverart (nti);
 	}
 
@@ -1653,7 +1822,6 @@ void update_track_from_file (iTunesDB *itdb, Track *track)
 
     trackpath = get_file_name_from_source (track, SOURCE_PREFER_LOCAL);
 
-    
     if (!(oetr->pc_path_locale && *oetr->pc_path_locale))
     { /* no path available */
 	if (trackpath)
@@ -2410,3 +2578,168 @@ gboolean read_soundcheck (Track *track)
     return result;
 }
 
+/* Get lyrics from file */
+gboolean read_lyrics_from_file (Track *track, gchar **lyrics)
+{
+    gchar *path;
+    gchar *buf;
+    gboolean result = FALSE;
+    ExtraTrackData *etr;
+
+    g_return_val_if_fail (track, FALSE);
+    etr = track->userdata;
+    g_return_val_if_fail (etr,FALSE);
+    path = get_file_name_from_source (track, SOURCE_PREFER_IPOD);
+    if (path)
+    {
+        switch (determine_file_type (path))
+        {
+        case FILE_TYPE_MP3:
+            result = id3_lyrics_read (path, lyrics);
+            break;
+        case FILE_TYPE_M4A:
+        case FILE_TYPE_M4P:
+        case FILE_TYPE_M4B:
+        case FILE_TYPE_M4V:
+        case FILE_TYPE_MP4:
+            result = TRUE;
+            *lyrics=g_strdup(
+                "File format unsupported now.");
+            break;
+        case FILE_TYPE_MOV:
+        case FILE_TYPE_MPG:
+        case FILE_TYPE_WAV: /* FIXME */
+        case FILE_TYPE_OGG: /* FIXME */
+        case FILE_TYPE_FLAC: /* FIXME */
+        case FILE_TYPE_UNKNOWN:
+            result = TRUE;
+            *lyrics=g_strdup(
+                "Lyrics not supported for this file format.");
+            break;
+        case FILE_TYPE_M3U:
+        case FILE_TYPE_PLS:
+        case FILE_TYPE_IMAGE:
+        case FILE_TYPE_DIRECTORY:
+            break;
+        }
+        g_free (path);
+    }
+    else
+    {
+        buf = get_track_info (track, FALSE);
+        gtkpod_warning (
+            _("Lyrics not found, file not available (%s).\n\n"),
+            buf);
+        g_free (buf);
+    }
+    if (result)
+    {
+	if (!*lyrics) *lyrics=g_strdup("");
+	if (etr->lyrics) g_free(etr->lyrics);
+	etr->lyrics=g_strdup(*lyrics);
+    }
+    return result;
+}
+
+/* Write lyrics to file */
+gboolean write_lyrics_to_file (Track *track)
+{
+    gchar *path=NULL;
+    gchar *buf;
+    Track *oldtrack;
+    gboolean result = FALSE;
+    gboolean warned = FALSE;
+    ExtraTrackData *etr;
+    iTunesDB *itdb;
+
+    g_return_val_if_fail (track, FALSE);
+    etr = track->userdata;
+    g_return_val_if_fail (etr,FALSE);
+    itdb = track->itdb;
+    g_return_val_if_fail (itdb, FALSE);
+    path = get_file_name_from_source (track, SOURCE_IPOD);
+    if (!path)
+    {
+	if (prefs_get_int("id3_write"))
+	{
+	    path = get_file_name_from_source (track, SOURCE_LOCAL);
+	}
+	else
+	{
+	    buf = get_track_info (track, FALSE);
+	    gtkpod_warning (
+			_("iPod File not available and ID3 saving disabled in options, cannot save lyrics to: %s.\n\n"),
+			buf);
+	    g_free (buf);
+	    warned=TRUE;
+	}
+    }
+    if (path!=NULL)
+    {
+        switch (determine_file_type (path))
+        {
+        case FILE_TYPE_MP3:
+            result = id3_lyrics_save (path, etr->lyrics);
+            break;
+        case FILE_TYPE_M4A:
+        case FILE_TYPE_M4P:
+        case FILE_TYPE_M4B:
+        case FILE_TYPE_M4V:
+        case FILE_TYPE_MP4:
+            result = TRUE;
+            break;
+        case FILE_TYPE_MOV:
+        case FILE_TYPE_MPG:
+        case FILE_TYPE_WAV: /* FIXME */
+        case FILE_TYPE_OGG: /* FIXME */
+        case FILE_TYPE_FLAC: /* FIXME */
+        case FILE_TYPE_UNKNOWN:
+            result = TRUE;
+            break;
+        case FILE_TYPE_M3U:
+        case FILE_TYPE_PLS:
+        case FILE_TYPE_IMAGE:
+        case FILE_TYPE_DIRECTORY:
+            break;
+        }
+        g_free (path);
+    }
+    else
+    {
+	if (!warned) {
+	    buf = get_track_info (track, FALSE);
+	    gtkpod_warning (
+		_("Lyrics not written, file name not available (%s).\n\n"),
+		buf);
+	    g_free (buf);
+	}
+    }
+
+    if (!result || !etr->lyrics || (strlen(etr->lyrics)==0))
+    {
+	track->lyrics_flag=0x00;
+    }
+    else
+    {
+	track->lyrics_flag=0x01;
+    }
+    if (!etr->lyrics)
+    {
+	etr->lyrics = g_strdup ("");
+    }
+
+    if (result)
+    {
+	/* remove track from sha1 hash and reinsert it (hash value has changed!) */
+	sha1_track_remove (track);
+	C_FREE (etr->sha1_hash);  /* need to remove the old value manually! */
+	oldtrack = sha1_track_exists_insert (itdb, track);
+	if (oldtrack)
+	{ /* track exists, remove the old track and register the new version */
+	    sha1_track_remove (oldtrack);
+	    gp_duplicate_remove (track, oldtrack);
+	    sha1_track_exists_insert (itdb, track);
+	}
+    }
+    return result;
+}
