@@ -1,5 +1,4 @@
-/* Time-stamp: <2007-02-24 13:22:58 jcs>
-|
+/*
 |  Copyright (C) 2002 Corey Donohoe <atmos at atmos.org>
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -25,7 +24,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: file_export.c 1824 2007-12-13 10:51:04Z dforsi $
+|  $Id: file_export.c 2208 2009-01-13 13:17:43Z jcsjcs $
 */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -73,8 +72,7 @@ const gchar *EXPORT_FILES_CHECK_EXISTING="export_files_check_existing";
 const gchar *EXPORT_FILES_PATH="export_files_path";
 const gchar *EXPORT_FILES_TPL="export_files_template";
 /* Default prefs settings */
-const gchar *EXPORT_FILES_TPL_DFLT="%o;%a - %t.mp3;%t.wav";
-
+const gchar *EXPORT_FILES_TPL_DFLT="%o;%a - %t.m4a;%a - %t.mp3;%t.wav";
 
 /**
  * READ_WRITE_BLOCKSIZE - how many bytes we read per fread/fwrite call
@@ -591,10 +589,10 @@ void export_files_init (GList *tracks, GList **filenames,
 	GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 	NULL);
 
-    export_files_xml = glade_xml_new (xml_file, "export_files_options", NULL);
+    export_files_xml = gtkpod_xml_new (xml_file, "export_files_options");
     win = gtkpod_xml_get_widget (export_files_xml, "export_files_options");
-    options = gtkpod_xml_get_widget (export_files_xml, "options_frame");
-    message_box = gtkpod_xml_get_widget (export_files_xml, "message_box");
+    options = gtkpod_xml_get_widget (export_files_xml, "ef_options_frame");
+    message_box = gtkpod_xml_get_widget (export_files_xml, "ef_message_box");
 
     /* Information needed to clean up later */
     fcd = g_malloc0 (sizeof (struct fcd));
@@ -619,9 +617,9 @@ void export_files_init (GList *tracks, GList **filenames,
     {
 	GList *gl;
 	GtkWidget *label = gtkpod_xml_get_widget (export_files_xml,
-						 "message");
+						 "ef_message");
 	GtkWidget *tv = gtkpod_xml_get_widget (export_files_xml,
-					      "textview");
+					      "ef_textview");
 	GtkTextBuffer *tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW(tv));
 	if (message)  gtk_label_set_text (GTK_LABEL (label), message);
 	else          gtk_widget_hide (label);
@@ -1091,10 +1089,10 @@ void export_playlist_file_init (GList *tracks)
 	NULL);
     GladeXML *export_playlist_xml;
     
-    export_playlist_xml = glade_xml_new (xml_file, "export_playlist_file_options", NULL);
+    export_playlist_xml = gtkpod_xml_new (xml_file, "export_playlist_file_options");
     win = gtkpod_xml_get_widget (export_playlist_xml, "export_playlist_file_options");
 
-    options = gtkpod_xml_get_widget (export_playlist_xml, "options_frame");
+    options = gtkpod_xml_get_widget (export_playlist_xml, "ep_options_frame");
 
     fcd->win_xml = export_playlist_xml;
 
