@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: file_itunesdb.c 1824 2007-12-13 10:51:04Z dforsi $
+|  $Id: file_itunesdb.c 2221 2009-01-18 05:30:42Z tmzullinger $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -54,6 +54,9 @@
 #define debug(s) printf(__FILE__":" TO_STR(__LINE__) ":" s)
 #define debugx(s,...) printf(__FILE__":" TO_STR(__LINE__) ":" s,__VA_ARGS__)
 
+#define WRITE_EXTENDED_INFO TRUE
+/* #define WRITE_EXTENDED_INFO prefs_get_int("write_extended_info") */
+
 /*------------------------------------------------------------------*\
  *                                                                  *
  *      Handle Import of iTunesDB                                   *
@@ -78,6 +81,7 @@ struct track_extended_info
     guint64 local_itdb_id;
     guint64 local_track_dbid;
     gboolean transferred;
+    gchar *lyrics;
 };
 
 typedef struct {
@@ -144,6 +148,8 @@ void fill_in_extended_info (Track *track, gint32 total, gint32 num)
   }
   if (sei) /* found info for this id! */
   {
+      etr->lyrics=NULL;
+      sei->lyrics=NULL;
       if (sei->pc_path_locale && !etr->pc_path_locale)
       {
 	  etr->pc_path_locale = g_strdup (sei->pc_path_locale);
@@ -229,12 +235,22 @@ static gboolean read_extended_info (gchar *name, gchar *itunes)
     struct track_extended_info *sei = NULL;
     FILE *fp;
 
+    g_return_val_if_fail (itunes, FALSE);
+
+    if (!name)
+    {   /* name can be NULL if it does not exist on the iPod */
+	return FALSE;
+    }
 
     fp = fopen (name, "r");
+
     if (!fp)
     {
+	/* Ideally, we'd only warn when we know we've written the extended info
+	 * previously...
 	gtkpod_warning (_("Could not open \"%s\" for reading extended info.\n"),
 			name);
+	*/
 	return FALSE;
     }
     sha1 = sha1_hash_on_filename (itunes, FALSE);
@@ -297,6 +313,7 @@ static gboolean read_extended_info (gchar *name, gchar *itunes)
 	    {
 		if (sei->ipod_id != 0)
 		{ /* normal extended information */
+		    sei->lyrics=NULL;
 		    if (hash_matched)
 		    {
 			if (!extendedinfohash)
@@ -337,6 +354,7 @@ static gboolean read_extended_info (gchar *name, gchar *itunes)
 	    {
 		sei = g_malloc0 (sizeof (struct track_extended_info));
 		sei->ipod_id = atoi (arg);
+		sei->lyrics=NULL;
 	    }
 	}
 	else if (g_ascii_strcasecmp (line, "version") == 0)
@@ -410,7 +428,7 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 			  const gchar *mp, const gchar *name_off,
 			  const gchar *name_loc)
 {
-    gchar *cfgdir = prefs_get_cfgdir ();
+    gchar *cfgdir;
     GList *gl;
     Playlist *pod_pl;
     ExtraiTunesDBData *eitdb;
@@ -423,6 +441,8 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
     g_return_val_if_fail (!(type & GP_ITDB_TYPE_LOCAL) || name_loc, NULL);
     g_return_val_if_fail (!(type & GP_ITDB_TYPE_IPOD) || 
 			  (mp && name_off), NULL);
+
+    cfgdir = prefs_get_cfgdir ();
     g_return_val_if_fail (cfgdir, NULL);
 
     if (old_itdb)
@@ -450,7 +470,7 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 
 	if (g_file_test (name_db, G_FILE_TEST_EXISTS))
 	{
-	    if (prefs_get_int("write_extended_info"))
+	    if (WRITE_EXTENDED_INFO)
 	    {
 		if (!read_extended_info (name_ext, name_db))
 		{
@@ -499,7 +519,6 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	}
 	g_free (name_ext);
 	g_free (name_db);
-	g_free (cfgdir);
     }
     else
     { /* GP_ITDB_TYPE_IPOD _and_ iPod is connected */
@@ -554,6 +573,7 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	g_free (name_db);
 	g_free (itunes_dir);
     }
+    g_free (cfgdir);
 
     if (!itdb)
     {
@@ -602,7 +622,7 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	{   /* if has_artwork is not set (0x00), or it has been
 	       (potentially wrongly) set to 0x02 by gtkpod V0.99 or
 	       smaller, determine the correct(?) value */
-	    if (track->artwork->thumbnails)
+	    if (itdb_track_has_thumbnails (track))
 		track->has_artwork = 0x01;
 	    else
 		track->has_artwork = 0x02;
@@ -612,7 +632,7 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	if (track->mediatype == 0)
 	    track->mediatype = 0x00000001;
 	/* restore deleted thumbnails */
-	if ((track->artwork->thumbnails == NULL) &&
+	if ((!itdb_track_has_thumbnails (track)) &&
 	    (strlen (etr->thumb_path_locale) != 0))
 	{
 	    /* !! gp_track_set_thumbnails() writes on
@@ -802,9 +822,13 @@ static iTunesDB *gp_merge_itdb (iTunesDB *old_itdb)
 				   mountpoint,
 				   old_eitdb->offline_filename,
 				   NULL);
+	if (new_itdb)
+	    gphoto_load_photodb (new_itdb);
     }
     else
+    {
 	g_return_val_if_reached (NULL);
+    }
 
     if (new_itdb)
     {
@@ -862,25 +886,24 @@ iTunesDB *gp_load_ipod (iTunesDB *itdb)
     itunesdb = itdb_get_itunesdb_path (mountpoint);
     if (!itunesdb)
     {
-	gchar *str = g_strdup_printf (_("Could not find iPod directory structure at '%s'.\nIf you are sure that the iPod is properly mounted at '%s', gtkpod can create the directory structure for you.\n\nDo you want to create the directory structure now?\n"), mountpoint, mountpoint);
-	GtkWidget *dialog = gtk_message_dialog_new (
-	    GTK_WINDOW (gtkpod_window),
-	    GTK_DIALOG_DESTROY_WITH_PARENT,
-	    GTK_MESSAGE_WARNING,
-	    GTK_BUTTONS_YES_NO,
-	    str);
-	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-	g_free (str);
+		gchar *str = g_strdup_printf (_("Could not find iPod directory structure at '%s'.\n\nIf you are sure that the iPod is properly mounted at '%s', it may not be initialized for use. In this case, gtkpod can initialize it for you.\n\nDo you want to create the directory structure now?"), mountpoint, mountpoint);
+		
+		gint result = gtkpod_confirmation_simple (GTK_WINDOW (gtkpod_window),
+												  GTK_MESSAGE_WARNING,
+												  _("iPod directory structure not found"),
+												  str,
+												  _("Create directory structure"));
+			
+		g_free (str);
 
-	if (result == GTK_RESPONSE_YES)
-	{
-	    ok_to_load = gp_ipod_init (itdb);
-	}
-	else
-	{
-	    ok_to_load = FALSE;
-	}
+		if (result == GTK_RESPONSE_OK)
+		{
+			ok_to_load = gp_ipod_init (itdb);
+		}
+		else
+		{
+			ok_to_load = FALSE;
+		}
     }
     g_free (itunesdb);
     g_free (mountpoint);
@@ -987,8 +1010,6 @@ iTunesDB *gp_load_ipod (iTunesDB *itdb)
 	}
     }
     
-    /* All successfully loaded so try loading the photo database */
-    gphoto_load_photodb (new_itdb);
     return new_itdb;
 }
 
@@ -1343,7 +1364,7 @@ static GtkWidget *create_transfer_information_dialog (TransferData *td)
     GladeXML *dialog_xml;
     GtkWidget *dialog, *widget;
 
-    dialog_xml = glade_xml_new (xml_file, "file_transfer_information_dialog", NULL);
+    dialog_xml = gtkpod_xml_new (xml_file, "file_transfer_information_dialog");
     glade_xml_signal_autoconnect (dialog_xml);
 
     dialog = gtkpod_xml_get_widget (dialog_xml, "file_transfer_information_dialog");
@@ -1605,6 +1626,7 @@ static void transfer_tracks_show_failed (iTunesDB *itdb, TransferData *td)
 	g_return_if_fail (tr && tr->userdata);
 
 	etr = tr->userdata;
+	etr->lyrics=NULL;
 
 	buf = get_track_info (tr, FALSE);
 
@@ -1849,21 +1871,24 @@ static gboolean gp_write_itdb (iTunesDB *itdb)
       }
       if (g_file_test (tunes, G_FILE_TEST_EXISTS))
       {
-	  gchar *str = g_strdup_printf (_("You did not import the existing iTunesDB ('%s'). This is most likely incorrect and will result in the loss of the existing database.\n\nPress 'OK' if you want to proceed anyhow or 'Cancel' to skip storing. If you cancel, you can import the existing database before calling this function again.\n"), tunes);
-	  GtkWidget *dialog = gtk_message_dialog_new (
-	      GTK_WINDOW (gtkpod_window),
-	      GTK_DIALOG_DESTROY_WITH_PARENT,
-	      GTK_MESSAGE_WARNING,
-	      GTK_BUTTONS_OK_CANCEL,
-	      str);
-	  gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-	  gtk_widget_destroy (dialog);
-	  g_free (str);
-	  if (result == GTK_RESPONSE_CANCEL)
-	  {
-	      g_free (cfgdir);
-	      return FALSE;
-	  }
+		  gchar *str = g_strdup_printf (_("You did not import the existing iTunesDB ('%s'). This is most likely incorrect and will result in the loss of the existing database.\n\nIf you skip storing, you can import the existing database before calling this function again.\n"), tunes);
+
+		  gint result = gtkpod_confirmation_hig (GTK_WINDOW (gtkpod_window),
+											     GTK_MESSAGE_WARNING,
+											     _("Existing iTunes database not imported"),
+											     str,
+											     _("Proceed anyway"),
+												 _("Skip storing"),
+												 NULL,
+												 NULL);
+			
+		  g_free (str);
+		  
+		  if (result == GTK_RESPONSE_CANCEL)
+		  {
+			  g_free (cfgdir);
+			  return FALSE;
+		  }
       }
   }
 
@@ -1965,7 +1990,7 @@ static gboolean gp_write_itdb (iTunesDB *itdb)
 	      }
 	  }
       }
-      if (success && cfgdir)
+      if (success)
       {   /* copy to cfgdir */
 	  GError *error = NULL;
 	  if (!itdb_cp (itdb->filename, eitdb->offline_filename, &error))
@@ -2043,7 +2068,7 @@ static gboolean gp_write_itdb (iTunesDB *itdb)
    */
   if (success &&  
 		  (itdb->usertype & GP_ITDB_TYPE_IPOD) &&
-		  gphoto_ipod_supports_photos (itdb) &&
+		  itdb_device_supports_photo (itdb->device) &&
 		  eitdb->photodb != NULL &&
 		  eitdb->photo_data_changed == TRUE)
   {
@@ -2138,9 +2163,19 @@ void data_changed (iTunesDB *itdb)
     eitdb = itdb->userdata;
     g_return_if_fail (eitdb);
 
-    eitdb->data_changed = TRUE;
-    pm_itdb_name_changed (itdb);
-    space_data_update ();
+    if ((itdb->usertype & GP_ITDB_TYPE_IPOD) && !eitdb->itdb_imported)
+    {   /* don't do anything for non-imported iPod
+	   repositories. Marking them as "changed" allows the empty
+	   repository to be saved back to the iPod, overwriting data
+	   there */
+	return;
+    }
+    else
+    {
+	eitdb->data_changed = TRUE;
+	pm_itdb_name_changed (itdb);
+	space_data_update ();
+    }
 }
 
 
