@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: info.c 1550 2007-06-17 14:14:38Z jcsjcs $
+|  $Id: info.c 1894 2008-01-01 19:26:37Z Sikon $
 */
 
 /* This file provides functions for the info window as well as for the
@@ -63,14 +63,80 @@ static iTunesDB *space_itdb = NULL; /* semi thread save access
 static gdouble space_ipod_free = 0; /* thread save access through mutex */
 static gdouble space_ipod_used = 0; /* thread save access through mutex */
 
+static GList *callbacks_info_update = NULL;
+static GList *callbacks_info_update_track_view = NULL;
+static GList *callbacks_info_update_playlist_view = NULL;
+static GList *callbacks_info_update_totals_view = NULL;
 
-static gdouble get_ipod_free_space(void);
 #if 0
 static gdouble get_ipod_used_space(void);
 #endif
 
+/* callback management */
+static void register_callback (GList **list, info_update_callback cb)
+{
+	if(*list && g_list_index (*list, cb) != -1)
+		return;
+	
+	*list = g_list_append (*list, cb);
+}
+
+static void unregister_callback (GList **list, info_update_callback cb)
+{
+	if(*list)
+		*list = g_list_remove (*list, cb);
+}
+
+static void callback_call_all (GList *list)
+{
+	for(; list; list = list->next)
+	{
+		((info_update_callback) list->data) ();
+	}
+}
+
+void register_info_update (info_update_callback cb)
+{
+	register_callback (&callbacks_info_update, cb);
+}
+
+void register_info_update_track_view (info_update_callback cb)
+{
+	register_callback (&callbacks_info_update_track_view, cb);
+}
+
+void register_info_update_playlist_view (info_update_callback cb)
+{
+	register_callback (&callbacks_info_update_playlist_view, cb);
+}
+
+void register_info_update_totals_view (info_update_callback cb)
+{
+	register_callback (&callbacks_info_update_totals_view, cb);
+}
+
+void unregister_info_update (info_update_callback cb)
+{
+	unregister_callback (&callbacks_info_update, cb);
+}
+
+void unregister_info_update_track_view (info_update_callback cb)
+{
+	unregister_callback (&callbacks_info_update_track_view, cb);
+}
+
+void unregister_info_update_playlist_view (info_update_callback cb)
+{
+	unregister_callback (&callbacks_info_update_playlist_view, cb);
+}
+
+void unregister_info_update_totals_view (info_update_callback cb)
+{
+	unregister_callback (&callbacks_info_update_totals_view, cb);
+}
+
 /* fill in tracks, playtime and filesize from track list @tl */
-static void fill_in_info (GList *tl, guint32 *tracks,
+void fill_in_info (GList *tl, guint32 *tracks,
 			  guint32 *playtime, gdouble *filesize)
 {
     GList *gl;
@@ -153,67 +219,11 @@ static void fill_label_string (gchar *w_name, const char *str)
     }
 }
 
-
-
-/* open info window */
-void info_open_window (void)
-{
-    if (info_window)
-    {   /* info window already open -- raise to the top */
-	gdk_window_raise (info_window->window);
-	return;
-    }
-    
-    info_xml = glade_xml_new (xml_file, "gtkpod_info", NULL);
-    glade_xml_signal_autoconnect (info_xml);
-    info_window = gtkpod_xml_get_widget (info_xml, "gtkpod_info");
-    
-    if (info_window)
-    {
-	gint defx, defy;
-	defx = prefs_get_int("size_info.x");
-  defy = prefs_get_int("size_info.y");
-	gtk_window_set_default_size (GTK_WINDOW (info_window), defx, defy);
-	prefs_set_int("info_window", TRUE); /* notify prefs */
-	info_update ();
-	gtk_widget_show (info_window);
-	/* set the menu item for the info window correctly */
-	display_set_info_window_menu ();
-    }
-}
-
-/* close info window */
-void info_close_window (void)
-{
-    GtkWidget *win;
-
-    if (!info_window) return; /* not open */
-
-    info_update_default_sizes ();
-    win = info_window;
-    info_window = NULL;
-    gtk_widget_destroy (win);
-     prefs_set_int("info_window", FALSE); /* notify prefs */
-    /* set the menu item for the info window correctly */
-    display_set_info_window_menu ();
-}
-
-/* save current window size */
-void info_update_default_sizes (void)
-{
-    if (info_window)
-    {
-	gint defx, defy;
-	gtk_window_get_size (GTK_WINDOW (info_window), &defx, &defy);
-	prefs_set_int("size_info.x", defx);
-	prefs_set_int("size_info.y", defy);
-    }
-}
-
 /* update all sections of info window */
 void info_update (void)
 {
-    if (!info_window) return; /* not open */
+	callback_call_all (callbacks_info_update);
+	
     info_update_track_view ();
     info_update_playlist_view ();
     info_update_totals_view ();
@@ -225,7 +235,7 @@ static void info_update_track_view_displayed (void)
     gdouble  filesize;        /* in bytes */
     GList *displayed;
 
-    g_return_if_fail (info_window);
+    if (!info_window) return; /* not open */
     displayed = display_get_selected_members (prefs_get_int("sort_tab_num")-1);
     fill_in_info (displayed, &tracks, &playtime, &filesize);
     fill_label_uint ("tracks_displayed", tracks);
@@ -233,7 +243,7 @@ static void info_update_track_view_displayed (void)
     fill_label_size ("filesize_displayed", filesize);
 }
 
-void info_update_track_view_selected (void)
+static void info_update_track_view_selected (void)
 {
     guint32 tracks, playtime; /* playtime in secs */
     gdouble  filesize;        /* in bytes */
@@ -251,7 +261,9 @@ void info_update_track_view_selected (void)
 /* update track view section */
 void info_update_track_view (void)
 {
-    if (!info_window) return; /* not open */
+	callback_call_all (callbacks_info_update_track_view);
+
+	if (!info_window) return; /* not open */
     info_update_track_view_displayed ();
     info_update_track_view_selected ();
 }
@@ -259,7 +271,9 @@ void info_update_track_view (void)
 /* update playlist view section */
 void info_update_playlist_view (void)
 {
-    guint32 tracks, playtime; /* playtime in secs */
+	callback_call_all (callbacks_info_update_playlist_view);
+
+	guint32 tracks, playtime; /* playtime in secs */
     gdouble  filesize;        /* in bytes */
     GList   *tl;
 
@@ -273,7 +287,7 @@ void info_update_playlist_view (void)
 
 
 /* Get the local itdb */
-static iTunesDB *get_itdb_local (void)
+iTunesDB *get_itdb_local (void)
 {
     struct itdbs_head *itdbs_head;
     GList *gl;
@@ -296,7 +310,7 @@ static iTunesDB *get_itdb_local (void)
 /* Get the iPod itdb */
 /* FIXME: This function must be expanded if support for several iPods
    is implemented */
-static iTunesDB *get_itdb_ipod (void)
+iTunesDB *get_itdb_ipod (void)
 {
     struct itdbs_head *itdbs_head;
     GList *gl;
@@ -315,46 +329,8 @@ static iTunesDB *get_itdb_ipod (void)
     return NULL;
 }
 
-
-/* update "totals" view section */
-void info_update_totals_view (void)
-{
-    guint32 tracks=0, playtime=0; /* playtime in secs */
-    gdouble  filesize=0;          /* in bytes */
-    Playlist *pl;
-    iTunesDB *itdb;
-
-    if (!info_window) return; /* not open */
-    
-    itdb = get_itdb_ipod ();
-    if (itdb)
-    {
-	pl = itdb_playlist_mpl (itdb);
-	g_return_if_fail (pl);
-	fill_in_info (pl->members, &tracks, &playtime, &filesize);
-	fill_label_uint ("total_playlists_ipod",
-			 itdb_playlists_number (itdb)-1);
-	fill_label_uint ("total_tracks_ipod", tracks);
-	fill_label_time ("total_playtime_ipod", playtime);
-	fill_label_size ("total_filesize_ipod", filesize);
-    }
-    itdb = get_itdb_local ();
-    if (itdb)
-    {
-	pl = itdb_playlist_mpl (itdb);
-	g_return_if_fail (pl);
-	fill_in_info (pl->members, &tracks, &playtime, &filesize);
-	fill_label_uint ("total_playlists_local",
-			 itdb_playlists_number (itdb)-1);
-	fill_label_uint ("total_tracks_local", tracks);
-	fill_label_time ("total_playtime_local", playtime);
-	fill_label_size ("total_filesize_local", filesize);
-    }
-    info_update_totals_view_space ();
-}
-
 /* update "free space" section of totals view */
-void info_update_totals_view_space (void)
+static void info_update_totals_view_space (void)
 {
     gdouble nt_filesize, del_filesize;
     guint32 nt_tracks, del_tracks;
@@ -390,6 +366,44 @@ void info_update_totals_view_space (void)
     }
 }
 
+/* update "totals" view section */
+void info_update_totals_view (void)
+{
+    guint32 tracks=0, playtime=0; /* playtime in secs */
+    gdouble  filesize=0;          /* in bytes */
+    Playlist *pl;
+    iTunesDB *itdb;
+
+	callback_call_all (callbacks_info_update_totals_view);
+
+	if (!info_window) return; /* not open */
+    
+    itdb = get_itdb_ipod ();
+    if (itdb)
+    {
+	pl = itdb_playlist_mpl (itdb);
+	g_return_if_fail (pl);
+	fill_in_info (pl->members, &tracks, &playtime, &filesize);
+	fill_label_uint ("total_playlists_ipod",
+			 itdb_playlists_number (itdb)-1);
+	fill_label_uint ("total_tracks_ipod", tracks);
+	fill_label_time ("total_playtime_ipod", playtime);
+	fill_label_size ("total_filesize_ipod", filesize);
+    }
+    itdb = get_itdb_local ();
+    if (itdb)
+    {
+	pl = itdb_playlist_mpl (itdb);
+	g_return_if_fail (pl);
+	fill_in_info (pl->members, &tracks, &playtime, &filesize);
+	fill_label_uint ("total_playlists_local",
+			 itdb_playlists_number (itdb)-1);
+	fill_label_uint ("total_tracks_local", tracks);
+	fill_label_time ("total_playtime_local", playtime);
+	fill_label_size ("total_filesize_local", filesize);
+    }
+    info_update_totals_view_space ();
+}
 
 /*------------------------------------------------------------------*\
  *                                                                  *
@@ -749,7 +763,7 @@ static gpointer th_space_thread (gpointer gp)
 
 
 /* in Bytes */
-static gdouble get_ipod_free_space(void)
+gdouble get_ipod_free_space(void)
 {
     gdouble result;
     g_mutex_lock (space_mutex);
