@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: info.h 1065 2007-05-06 14:16:17Z jcsjcs $
+|  $Id: info.h 1894 2008-01-01 19:26:37Z Sikon $
 */
 
 #ifndef __INFO_H__
@@ -36,16 +36,30 @@
 #include <glib.h>
 #include "itdb.h"
 
+/* callbacks */
+typedef void (*info_update_callback) ();
+
+void register_info_update (info_update_callback cb);
+void register_info_update_track_view (info_update_callback cb);
+void register_info_update_playlist_view (info_update_callback cb);
+void register_info_update_totals_view (info_update_callback cb);
+
+void unregister_info_update (info_update_callback cb);
+void unregister_info_update_track_view (info_update_callback cb);
+void unregister_info_update_playlist_view (info_update_callback cb);
+void unregister_info_update_totals_view (info_update_callback cb);
+
+/* generic functions */
+void fill_in_info (GList *tl, guint32 *tracks, guint32 *playtime, gdouble *filesize);
+iTunesDB *get_itdb_ipod (void);
+iTunesDB *get_itdb_local (void);
+gdouble get_ipod_free_space(void);
+
 /* info window */
-void info_open_window (void);
-void info_close_window (void);
-void info_update_default_sizes (void);
 void info_update (void);
 void info_update_track_view (void);
-void info_update_track_view_selected (void);
 void info_update_playlist_view (void);
 void info_update_totals_view (void);
-void info_update_totals_view_space (void);
 
 /* statusbar stuff */
 #define STATUSBAR_TIMEOUT 4200
