@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc.h 1814 2007-12-11 12:53:22Z jcsjcs $
+|  $Id: misc.h 1908 2008-01-03 14:38:30Z Sikon $
 */
 
 #ifndef __MISC_H__
@@ -75,27 +75,10 @@ extern gchar *xml_file;
 
 /* Some symbols not necessarily defined */
 
-/* Introduced in 2.6 */
-#ifndef GTK_STOCK_DISCONNECT
-#define GTK_STOCK_DISCONNECT GTK_STOCK_GOTO_TOP
-#define GTK_STOCK_CONNECT GTK_STOCK_GOTO_BOTTOM
-#endif
-#ifndef GTK_STOCK_EDIT
-#define GTK_STOCK_EDIT NULL
-#endif
-#ifndef G_IS_DIR_SEPARATOR
-#define G_IS_DIR_SEPARATOR(c) (c == G_DIR_SEPARATOR)
-#endif
-/* SEMIBOLD was introduced with version 2.8 */
-#ifndef PANGO_WEIGHT_SEMIBOLD
-#define PANGO_WEIGHT_SEMIBOLD 600
-#endif
-
-
-
+gchar *utf8_strcasestr (const gchar *haystack, const gchar *needle);
 
 gchar *get_user_string (gchar *title, gchar *message, gchar *dflt,
-			gchar *opt_msg, gboolean *opt_state);
+			gchar *opt_msg, gboolean *opt_state, const gchar *accept_button);
 Playlist *add_new_pl_user_name (iTunesDB *itdb, gchar *dflt, gint32 pos);
 void add_new_pl_or_spl_user_name (iTunesDB *itdb, gchar *dflt, gint32 pos);
 void create_add_files_fileselector (void);
@@ -105,7 +88,6 @@ gchar *concat_dir_if_relative (G_CONST_RETURN gchar *base_dir,
 			       G_CONST_RETURN gchar *rel_dir);
 float get_ms_since (GTimeVal *old_time, gboolean update);
 gint get_sort_tab_number (gchar *text);
-void open_about_window (void);
 gboolean parse_tracks_from_string (gchar **s, Track **track);
 gboolean parse_artwork_from_string(gchar **s, Artwork **artwork);
 void gtkpod_init (int argc, char *argv[]);
@@ -143,6 +125,11 @@ gchar **build_argv_from_strings (const gchar *first_arg, ...);
 void delete_track_ok (struct DeleteData *dd);
 
 void gtkpod_warning (const gchar *format, ...);
+void gtkpod_warning_simple (const gchar *format, ...);
+void gtkpod_warning_hig (GtkWindow *parent,
+						 GtkMessageType icon,
+						 const gchar *primary_text,
+						 const gchar *secondary_text);
 
 gchar *time_time_to_string (time_t t);
 gchar *time_fromtime_to_string (time_t t);
@@ -239,6 +226,7 @@ GList *glist_duplicate (GList *list);
 
 gchar *which (const gchar *exe);
 
+GladeXML *gtkpod_xml_new (const gchar *xml_file, const gchar *name);
 GtkWidget *gtkpod_xml_get_widget (GladeXML *xml, const gchar *name);
 
 gchar *get_itdb_prefs_key (gint index, const gchar *subkey);
