@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_confirm.c 1822 2007-12-12 16:31:26Z dforsi $
+|  $Id: misc_confirm.c 2209 2009-01-13 13:45:55Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -82,6 +82,40 @@ void gtkpod_warning (const gchar *format, ...)
     g_free (text);
 }
 
+void gtkpod_warning_simple (const gchar *format, ...)
+{
+    va_list arg;
+    gchar *text;
+
+    va_start (arg, format);
+    text = g_strdup_vprintf (format, arg);
+    va_end (arg);
+	
+	gtkpod_warning_hig (GTK_WINDOW (gtkpod_window), GTK_MESSAGE_WARNING, _("Warning"), text);
+	g_free (text);
+}
+
+void gtkpod_warning_hig (GtkWindow *parent,
+						 GtkMessageType icon,
+						 const gchar *primary_text,
+						 const gchar *secondary_text)
+{
+	GtkWidget *dialog =	gtk_message_dialog_new(parent,
+						       GTK_DIALOG_MODAL,
+						       icon,
+						       GTK_BUTTONS_OK,
+						       "%s",
+						       primary_text);
+	
+	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG(dialog),
+						    "%s",
+						    secondary_text);
+	
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+
+}
+
 
 /*------------------------------------------------------------------*\
  *                                                                  *
@@ -826,33 +860,38 @@ void delete_playlist_head (DeleteAction deleteaction)
  *
  * return value: TRUE if it's OK to quit.
  */
-static gboolean
-ok_to_close_gtkpod (void)
+static gboolean ok_to_close_gtkpod (void)
 {
-    gint result = GTK_RESPONSE_YES;
+    gint result = GTK_RESPONSE_OK;
 
     if (!files_are_saved ())
     {
-	GtkWidget *dialog = gtk_message_dialog_new (
-	    GTK_WINDOW (gtkpod_window),
-	    GTK_DIALOG_DESTROY_WITH_PARENT,
-	    GTK_MESSAGE_WARNING,
-	    GTK_BUTTONS_YES_NO,
-	    _("Data has been changed and not been saved.\nOK to exit gtkpod?"));
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
+		const gchar *str = _("Data has been changed and not been saved. If you quit gtkpod, all unsaved changes will be lost.\n\nDo you want to save your changes first?");
+		
+		result = gtkpod_confirmation_hig(GTK_WINDOW (gtkpod_window),
+											GTK_MESSAGE_WARNING,
+											_("Save changes before quiting?"),
+											str,
+											GTK_STOCK_SAVE,
+											GTK_STOCK_CANCEL,
+											_("Quit without saving"),
+											NULL);
     }
 
-    if (result == GTK_RESPONSE_YES)
-    {
+	/* User pressed Cancel */
+    if (result == GTK_RESPONSE_CANCEL)
+		return FALSE;
+	
+	/* User pressed Save */
+	if (result == GTK_RESPONSE_OK)
+		handle_export ();
+	
 	return TRUE;
-    }
-    return FALSE;
 }
 
 
 /* callback for gtkpod window's close button */
-gboolean
+G_MODULE_EXPORT gboolean
 on_gtkpod_delete_event                 (GtkWidget       *widget,
 					GdkEvent        *event,
 					gpointer         user_data)
@@ -862,7 +901,9 @@ on_gtkpod_delete_event                 (GtkWidget       *widget,
 	if (ok_to_close_gtkpod ())
 	{
 	    gtkpod_shutdown ();
-	    return FALSE;
+	    /* returning FALSE to continue calling other handlers
+	       causes tons of errors. */
+	    return TRUE;
 	}
     }
     return TRUE; /* don't quit -- would cause numerous error messages */
@@ -870,7 +911,7 @@ on_gtkpod_delete_event                 (GtkWidget       *widget,
 
 
 /* callback for quit menu entry */
-void
+G_MODULE_EXPORT void
 on_quit1_activate                      (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
