@@ -1,5 +1,4 @@
-/* Time-stamp: <2006-06-24 01:53:45 jcs>
-|
+/*
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
 | 
@@ -24,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_playlist.c,v 1.38 2006/06/23 16:59:23 jcsjcs Exp $
+|  $Id: misc_playlist.c 1970 2008-05-11 06:07:12Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -35,7 +34,7 @@
 #include "charset.h"
 #include "itdb.h"
 #include "info.h"
-#include "md5.h"
+#include "sha1.h"
 #include "misc.h"
 #include "misc_track.h"
 #include "prefs.h"
@@ -58,16 +57,26 @@
 Playlist *add_new_pl_user_name (iTunesDB *itdb,
 				gchar *dflt, gint32 position)
 {
+    ExtraiTunesDBData *eitdb;
     Playlist *result = NULL;
     gchar *name;
 
     g_return_val_if_fail (itdb, NULL);
 
+    eitdb = itdb->userdata;
+    g_return_val_if_fail (eitdb, NULL);
+
+    if (!eitdb->itdb_imported)
+    {
+	gtkpod_warning_simple(_("Please load the iPod before adding playlists."));
+	return NULL;
+    }
+
     name = get_user_string (
 	_("New Playlist"),
 	_("Please enter a name for the new playlist"),
 	dflt? dflt:_("New Playlist"),
-	NULL, NULL);
+	NULL, NULL, GTK_STOCK_ADD);
     if (name)
     {
 	result = gp_playlist_add_new (itdb, name, FALSE, position);
@@ -85,16 +94,26 @@ Playlist *add_new_pl_user_name (iTunesDB *itdb,
 void add_new_pl_or_spl_user_name (iTunesDB *itdb,
 				  gchar *dflt, gint32 position)
 {
+    ExtraiTunesDBData *eitdb;
     gboolean is_spl = FALSE;
     gchar *name;
 
     g_return_if_fail (itdb);
 
+    eitdb = itdb->userdata;
+    g_return_if_fail (eitdb);
+
+    if (!eitdb->itdb_imported)
+    {
+	gtkpod_warning_simple(_("Please load the iPod before adding playlists."));
+	return;
+    }
+
     name = get_user_string (
 	_("New Playlist"),
 	_("Please enter a name for the new playlist"),
 	dflt? dflt:_("New Playlist"),
-	_("Smart Playlist"), &is_spl);
+	_("Smart Playlist"), &is_spl, GTK_STOCK_ADD);
 
     if (name)
     {
@@ -111,7 +130,7 @@ void add_new_pl_or_spl_user_name (iTunesDB *itdb,
 }
 
 /* callback */
-void
+G_MODULE_EXPORT void
 on_smart_playlist_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
@@ -429,7 +448,7 @@ Playlist *generate_new_playlist (iTunesDB *itdb, GList *tracks)
 	_("New Playlist"),
 	_("Please enter a name for the new playlist"),
 	_("New Playlist"),
-	NULL, NULL);
+	NULL, NULL, GTK_STOCK_ADD);
     if (name)
 	return generate_playlist_with_name (itdb, tracks, name, FALSE);
     return NULL;
@@ -914,7 +933,7 @@ check_db_danglingok1 (gpointer user_data1, gpointer user_data2)
         /* printf("Handling track %d\n", track->ipod_id); */
 
 	buf = get_track_info (track, TRUE);
-	gtkpod_statusbar_message (_("Processing '%s'"), buf);
+	gtkpod_statusbar_message (_("Processing '%s'..."), buf);
 	g_free (buf);
 				  
 	while (widgets_blocked && gtk_events_pending ())
@@ -922,19 +941,22 @@ check_db_danglingok1 (gpointer user_data1, gpointer user_data2)
 
 	/* Indicate that file needs to be transfered */
 	track->transferred=FALSE;
-	/* Update MD5 information */
-	/* remove track from md5 hash and reinsert it
+	/* Update SHA1 information */
+	/* remove track from sha1 hash and reinsert it
 	   (hash value may have changed!) */
-	md5_track_remove (track);
+	sha1_track_remove (track);
 	/* need to remove the old value manually! */
-	etr->md5_hash = NULL;
-	oldtrack = md5_track_exists_insert (itdb, track);
+	g_free (etr->sha1_hash);
+	etr->sha1_hash = NULL;
+	oldtrack = sha1_track_exists_insert (itdb, track);
 	if (oldtrack) { /* track exists, remove old track
 			  and register the new version */
-	    md5_track_remove (oldtrack);
+	    sha1_track_remove (oldtrack);
 	    gp_duplicate_remove (track, oldtrack);
-	    md5_track_exists_insert (itdb, track);
+	    sha1_track_exists_insert (itdb, track);
 	}
+	/* mark for conversion / transfer */
+	file_convert_add_track (track);
     }
     g_list_free(l_dangling);
     data_changed (itdb);
@@ -985,7 +1007,7 @@ void check_db (iTunesDB *itdb)
     Playlist* pl_orphaned = NULL;
     GList * l_dangling[2] = {NULL, NULL}; /* 2 kinds of dangling tracks: with approp
 					   * files and without */
-    /* 1 - Original file is present on PC and has the same md5*/
+    /* 1 - Original file is present on PC and has the same sha1*/
     /* 0 - Doesn't exist */
 
     gpointer foundtrack ;
@@ -1006,23 +1028,26 @@ void check_db (iTunesDB *itdb)
        a mistake and we should tell him about it */
     if (!eitdb->itdb_imported)
     {
-	gchar *itunesdb_filename = itdb_get_itunesdb_path (mountpoint);
-	if (itunesdb_filename)
-	{
-	    GtkWidget *dialog = gtk_message_dialog_new (
-		GTK_WINDOW (gtkpod_window),
-		GTK_DIALOG_DESTROY_WITH_PARENT,
-		GTK_MESSAGE_WARNING,
-		GTK_BUTTONS_OK_CANCEL,
-		_("You did not import the existing iTunesDB. This is most likely incorrect and will result in the loss of the existing database.\n\nPress 'OK' if you want to proceed anyhow or 'Cancel' to abort. If you cancel, you can import the existing database before calling this function again.\n"));
-	    gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-	    gtk_widget_destroy (dialog);
-	    g_free (itunesdb_filename);
-	    if (result == GTK_RESPONSE_CANCEL)
-	    {
-		return;
-	    }
-	}
+		gchar *itunesdb_filename = itdb_get_itunesdb_path (mountpoint);
+
+		if (itunesdb_filename)
+		{
+			const gchar *str = _("You did not import the existing iTunesDB. This is most likely incorrect and will result in the loss of the existing database.\n\nIf you abort the operation, you can import the existing database before calling this function again.\n");
+
+			gint result = gtkpod_confirmation_hig (GTK_WINDOW (gtkpod_window),
+												   GTK_MESSAGE_WARNING,
+												   _("Existing iTunes database not imported"),
+												   str,
+												   _("Proceed anyway"),
+												   _("Abort operation"),
+												   NULL,
+												   NULL);
+
+			if (result == GTK_RESPONSE_CANCEL)
+			{
+				return;
+			}
+		}
     }
 
     gtkpod_statusbar_timeout (30*STATUSBAR_TIMEOUT);
@@ -1124,7 +1149,7 @@ void check_db (iTunesDB *itdb)
 		    norphaned++;
 
                     if (localdebug) fprintf(stdout,"to orphaned ");
-		    if ((dupl_track = md5_file_exists (itdb, fn_orphaned,
+		    if ((dupl_track = sha1_file_exists (itdb, fn_orphaned,
 						       TRUE)))
 		    {  /* This orphan has already been added again.
 			  It will be removed with the next sync */
