@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_track.c 1686 2007-08-25 03:20:11Z jcsjcs $
+|  $Id: misc_track.c 2149 2008-11-08 09:38:35Z jcsjcs $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -882,6 +882,9 @@ gchar **track_get_item_pointer (Track *track, T_item t_item)
     case T_SORT_TVSHOW:
 	result = &track->sort_tvshow;
 	break;
+    case T_LYRICS:
+	result = &etr->lyrics;
+	break;
     case T_ALL:
     case T_IPOD_ID:
     case T_TRACK_NR:
@@ -989,6 +992,7 @@ gboolean track_copy_item (Track *frtrack, Track *totrack, T_item item)
     case T_SORT_ALBUMARTIST:
     case T_SORT_COMPOSER:
     case T_SORT_TVSHOW:
+    case T_LYRICS:
 	fritem = track_get_item (frtrack, item);
 	toitem_ptr = track_get_item_pointer (totrack, item);
 	g_return_val_if_fail (fritem, FALSE);
@@ -1007,6 +1011,10 @@ gboolean track_copy_item (Track *frtrack, Track *totrack, T_item item)
 		changed = TRUE;
 	    }
 	}
+	else if ((changed) && (item == T_LYRICS))
+	{
+	    write_lyrics_to_file (totrack);
+	}
 	/* handle items that have two entries */
 	if (item == T_PC_PATH)
 	{
@@ -1345,7 +1353,7 @@ gchar *track_get_text (Track *track, T_item item)
 	{   /* no path set */
 	    g_free (text);
 	    text = NULL;
-	    if (track->artwork && track->artwork->thumbnails)
+	    if (itdb_track_has_thumbnails (track))
 	    {   /* artwork is set */
 		text = g_strdup (_("Embedded or filename was lost"));
 	    }
@@ -1418,6 +1426,9 @@ gchar *track_get_text (Track *track, T_item item)
     case T_ITEM_NUM:
     case T_GAPLESS_TRACK_FLAG:
 	break;
+    case T_LYRICS:
+	read_lyrics_from_file (track, &text);
+	break;
     }
     return text;
 }
@@ -1501,6 +1512,15 @@ gboolean track_set_text (Track *track, const gchar *new_text, T_item item)
 	    changed = TRUE;
         }
         break;
+    case T_LYRICS:
+        if ((etr->lyrics == NULL) ||
+	    (strcmp(etr->lyrics,new_text) != 0))
+	{
+	    g_free(etr->lyrics);
+	    etr->lyrics=g_strdup(new_text);
+	    changed = TRUE;
+	}
+        break;
     case T_TRACK_NR:
         nr = atoi (new_text);
         if ((nr >= 0) && (nr != track->track_nr))
