@@ -1,4 +1,4 @@
-/* Time-stamp: <2006-06-11 13:57:01 jcs>
+/* Time-stamp: <2008-08-17 10:58:51 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: mp3file.h,v 1.24 2006/06/11 16:04:51 jcsjcs Exp $
+|  $Id: mp3file.h 2148 2008-11-08 08:02:15Z jcsjcs $
 */
 
 #ifndef MP3FILEH_INCLUDED
@@ -32,8 +32,12 @@
 
 #include "itdb.h"
 
-gboolean mp3_write_file_info (gchar *filename, Track *track);
-Track *mp3_get_file_info (gchar *name);
-gboolean mp3_read_soundcheck (gchar *path, Track *track);
+gboolean mp3_write_file_info (const gchar *filename, Track *track);
+Track *mp3_get_file_info (const gchar *name);
+gboolean mp3_read_soundcheck (const gchar *path, Track *track);
+gboolean mp3_read_gapless (const gchar *path, Track *track);
 
+gboolean id3_read_tags (const gchar *name, Track *track);
+gboolean id3_lyrics_read (const gchar *filename,gchar **lyrics);
+gboolean id3_lyrics_save (const gchar *filename,const gchar *lyrics);
 #endif
