@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: prefs.c 1776 2007-11-12 22:38:00Z phantom_sf $
+|  $Id: prefs.c 2216 2009-01-17 05:47:46Z jcsjcs $
 */
 
 /* -------------------------------------------------------------------
@@ -183,7 +183,9 @@ static void set_default_preferences()
     prefs_set_string ("path_play_now", "xmms %s");
     prefs_set_string ("path_play_enqueue", "xmms -e %s");
     prefs_set_string ("path_mserv_trackinfo_root", "/var/lib/mserv/trackinfo/");
-
+    prefs_set_string ("coverart_display_bg_color", "#000000");
+    prefs_set_string ("coverart_display_fg_color", "#FFFFFF");
+    
     str = g_build_filename (SCRIPTDIR, "convert-ogg2mp3.sh", NULL);
     prefs_set_string ("path_conv_ogg", str);
     g_free (str);
@@ -225,32 +227,34 @@ static void set_default_preferences()
     /* Set colum preferences */
     for (i = 0; i < TM_NUM_COLUMNS; i++)
     {
-	prefs_set_int_index("tm_col_width", i, 80);
-	prefs_set_int_index("col_visible", i, FALSE);
 	prefs_set_int_index("col_order", i, i);
     }
-		
-    for (i = 0; i < TM_NUM_TAGS_PREFS; i++)
-	prefs_set_int_index("tag_autoset", i, FALSE);
-		
-    prefs_set_int_index("tag_autoset", TM_COLUMN_TITLE, TRUE);
-    
+
     prefs_set_int_index("col_visible", TM_COLUMN_ARTIST, TRUE);
     prefs_set_int_index("col_visible", TM_COLUMN_ALBUM, TRUE);
     prefs_set_int_index("col_visible", TM_COLUMN_TITLE, TRUE);
-    prefs_set_int_index("col_visible", TM_COLUMN_GENRE, TRUE);
-    prefs_set_int_index("col_visible", TM_COLUMN_PLAYCOUNT, TRUE);
+    prefs_set_int_index("col_visible", TM_COLUMN_TRACKLEN, TRUE);
     prefs_set_int_index("col_visible", TM_COLUMN_RATING, TRUE);
 
+    for (i = 0; i < TM_NUM_TAGS_PREFS; i++)
+    {
+	prefs_set_int_index("tag_autoset", i, FALSE);
+    }
+
+    prefs_set_int_index("tag_autoset", TM_COLUMN_TITLE, TRUE);
+    
+    prefs_set_int("horizontal_scrollbar", TRUE);
+    prefs_set_int("filter_tabs_top", FALSE);
+
     /* Set pane positions--Let gtk worry about position */
     for (i = 0; i < PANED_NUM; i++)
 	prefs_set_int_index("paned_pos_", i, -1);
-	
+
     prefs_set_int("mpl_autoselect", TRUE);
-	
+
     /* Set window sizes */
-    prefs_set_int("size_gtkpod.x", 600);
-    prefs_set_int("size_gtkpod.y", 500);
+    prefs_set_int("size_gtkpod.x", 780);
+    prefs_set_int("size_gtkpod.y", 580);
     prefs_set_int("size_cal.x", 500);
     prefs_set_int("size_cal.y", 300);
     prefs_set_int("size_conf_sw.x", 300);
@@ -280,6 +284,7 @@ static void set_default_preferences()
     prefs_set_int("coverart_apic", TRUE);
     prefs_set_int("coverart_file", TRUE);
     prefs_set_string("coverart_template", "%A;folder.jpg");
+    prefs_set_string("video_thumbnailer_prog", "totem-video-thumbnailer %f %o");
     prefs_set_int("mserv_use", FALSE);
     prefs_set_string("mserv_username", "");
     prefs_set_int("startup_messages", TRUE);
@@ -296,7 +301,6 @@ static void set_default_preferences()
     prefs_set_int("display_toolbar", TRUE);
     prefs_set_int("toolbar_style", GTK_TOOLBAR_BOTH);
     prefs_set_int("sha1", TRUE);
-    prefs_set_string("export_template", "%o;%a - %t.mp3;%t.wav");
     prefs_set_int("file_dialog_details_expanded", FALSE);
 
     /* Set last browsed directory */
@@ -317,6 +321,9 @@ static void set_default_preferences()
     prefs_set_int("pm_sort", SORT_NONE);
     prefs_set_int("tm_sortcol", TM_COLUMN_TITLE);
     prefs_set_int("tm_sort", SORT_NONE);
+	
+	/* New conversion preferences */
+	prefs_set_int("conversion_target_format", TARGET_FORMAT_MP3);
 }
 
 /* Initialize default variable-length list entries */
@@ -360,8 +367,6 @@ static void usage(FILE *fp)
   locale_fprintf(fp, _("  --hash <file>:print gtkpod hash for file\n"));
   locale_fprintf(fp, _("  -m path:      define the mountpoint of your iPod\n"));
   locale_fprintf(fp, _("  --mountpoint: same as '-m'.\n"));
-  locale_fprintf(fp, _("  -a:           import database automatically after start.\n"));
-  locale_fprintf(fp, _("  --auto:       same as '-a'.\n"));
 }
 
 /* Parse commandline based options */
@@ -558,16 +563,17 @@ gchar *prefs_get_cfgdir()
     {
 	if ((g_mkdir(folder, 0777)) == -1)
 	{
-	    printf(_("Couldn't create ~/.gtkpod\n"));
+	    printf(_("Couldn't create '%s'\n"), folder);
+	    g_free (folder);
 	    return NULL;
 	}
     }
-	
     return folder;
 }
 
 
 /* get @key and @value from a string like "key=value" */
+/* you must g_free (*key) and (*value) after use */
 static gboolean read_prefs_get_key_value (const gchar *buf,
 					  gchar **key, gchar **value)
 {
@@ -781,7 +787,7 @@ TempPrefs *temp_prefs_load (const gchar *filename, GError **error)
 
 	do
 	{
-	    gchar *line;
+	    gchar *line = NULL;
 
 	    status = g_io_channel_read_line (gio, &line, NULL, NULL, error);
 	    if (status == G_IO_STATUS_NORMAL)
@@ -790,9 +796,11 @@ TempPrefs *temp_prefs_load (const gchar *filename, GError **error)
 		if (read_prefs_get_key_value (line, &key, &value))
 		{
 		    temp_prefs_set_string (temp_prefs, key, value);
+		    g_free (key);
+		    g_free (value);
 		}
-		g_free (line);
 	    }
+	    g_free (line);
 	} while (status == G_IO_STATUS_NORMAL);
 
 	g_io_channel_unref (gio);
@@ -838,7 +846,6 @@ static void wipe_list(const gchar *key)
 static void cleanup_keys()
 {
     gchar *buf;
-    gchar *sp = NULL;
     gint int_buf;
     gint i;
     gint x, y, p;  /* Window position */
@@ -1040,6 +1047,9 @@ static void cleanup_keys()
     prefs_set_string("size_file_dialog_details.y", NULL);
     prefs_set_string("autoimport", NULL);
     prefs_set_string("auto_import", NULL);
+    prefs_set_string("conversion_enable", NULL);
+    prefs_set_string("export_template", NULL);
+    prefs_set_string("filename_format", NULL);
 
     /* sp_created_cond renamed to sp_added_cond */
     for (i = 0; i < SORT_TAB_MAX; i++)
@@ -1146,50 +1156,6 @@ static void cleanup_keys()
 	prefs_set_string("sm_sort_", NULL);
     }
 
-    /* filename_format renamed to export_template */
-    if (prefs_get_string_value("filename_format", &buf))
-    {
-	prefs_set_string("export_template", buf);
-	g_free(buf);
-	prefs_set_string("filename_format", NULL);
-    }
-
-    /* This string was a wrong autoconvert--just ignore it */
-    buf = prefs_get_string("export_template");
-    
-    if (buf && strcmp(buf, "%a - %a/%T - %T.mp3") == 0)
-	prefs_set_string("export_template", NULL);
-
-    g_free (buf);
-
-    /* We changed the meaning of the %x in export_template */
-    if (version < 0.72)
-    {
-	/* changed the meaning of the %x in export_template */
-	if (sp) while (*sp)
-	{
-	    if (sp[0] == '%')
-	    {
-		switch (sp[1]) {
-		case 'A':
-		    sp[1] = 'a';
-		    break;
-		case 'd':
-		    sp[1] = 'A';
-		    break;
-		case 'n':
-		    sp[1] = 't';
-		    break;
-		case 't':
-		    sp[1] = 'T';
-		    break;
-		default:
-		    break;
-		}
-	    }
-	}
-    }
-
     /* For versions < 0.91, remove all itdb keys */
     if (version < 0.91)
 	prefs_flush_subkey("itdb_");
@@ -1300,6 +1266,22 @@ TempPrefs *temp_prefs_create ()
     return temp_prefs;	
 }
 
+static void copy_key_to_temp_prefs (gpointer key, gpointer value, gpointer user_data)
+{
+    temp_prefs_set_string ((TempPrefs *)user_data, key, value);
+}
+
+void temp_prefs_copy_prefs (TempPrefs *temp_prefs)
+{
+    g_return_if_fail (prefs_table);
+    g_return_if_fail (temp_prefs);
+    g_return_if_fail (temp_prefs->tree);
+
+	lock_prefs_table ();
+    g_hash_table_foreach (prefs_table, copy_key_to_temp_prefs, temp_prefs);
+	unlock_prefs_table ();
+}
+
 /* Delete temp prefs */
 void temp_prefs_destroy (TempPrefs *temp_prefs)
 {
@@ -2319,6 +2301,9 @@ GList *get_list_from_buffer(GtkTextBuffer *buffer)
 		
 	string_iter++;
     }
+
+    g_free (text_buffer);
+    g_strfreev (string_array);
     
     return list;
 }
