@@ -23,15 +23,15 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: tools.c 1684 2007-08-18 06:38:49Z jcsjcs $
+|  $Id: tools.c 1894 2008-01-01 19:26:37Z Sikon $
 */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
-
 #include "info.h"
+#include "infodlg.h"
 #include "misc.h"
 #include "misc_track.h"
 #include "mp3file.h"
@@ -877,19 +877,19 @@ void tools_enqueue_tracks (GList *selected_tracks)
 
    ------------------------------------------------------------ */
 
-gboolean
+G_MODULE_EXPORT gboolean
 on_gtkpod_info_delete_event            (GtkWidget       *widget,
 					GdkEvent        *event,
 					gpointer         user_data)
 {
-    info_close_window ();
+    close_info_dialog ();
     return TRUE; /* don't close again -- info_close_window() already does it */
 }
 
 
-void
+G_MODULE_EXPORT void
 on_info_close_clicked                  (GtkButton       *button,
 					gpointer         user_data)
 {
-    info_close_window ();
+    close_info_dialog ();
 }
